/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.model.shelf;

/**
 * A basic room in a warehouse. Stores information relating to the
 * area of the room, the percent of damage in the room, and the furnishings in
 * the room.
 *
 * @author Kyle
 *
 */
public class Shelf {

    private ShelfType shelfType;
    private ShelfSubType shelfSubType;
    private ShelfBaseType shelfBaseType;
    private int damage;
    private double shelfWidth;
    private double shelfLength;
    private double shelfHeight;
    private int shelfQuantity;
    private double shelfArea;
    private double shelfVolume;
    private int areausage;
    private int heightusage;
    private int shelfLevels;
    private int numPallet;
    
    public void setShelfBaseType(ShelfBaseType shelfBaseType) {
        this.shelfBaseType = shelfBaseType;
    }
    
    public ShelfBaseType getShelfBaseType() {
        return shelfBaseType;
    }
    
    public void setShelfSubType(ShelfSubType shelfSubType) {
        this.shelfSubType = shelfSubType;
    }
    
    public ShelfSubType getShelfSubType() {
        return shelfSubType;
    }
    
    public void setShelfLevels(int levels) {
        this.shelfLevels = levels;
    }
    
    public int getShelfLevels() {
        return shelfLevels;
    }

    public void setShelfType(ShelfType shelftype) {
        shelfType = shelftype;
    }
    
    public ShelfType getShelfType() {
        return shelfType;
    }
    
    public void setShelfQuantity(int shelfquantity) {
        this.shelfQuantity = shelfquantity;
    }
    
    public int getShelfQuantity() {
        return shelfQuantity;
    }

    public void setShelfWidth(double width) {
        this.shelfWidth = width;
    }
    
    public double getShelfWidth(){
        return shelfWidth;
    }
    
    public void setShelfLength(double length) {
        this.shelfLength = length;
    }
    
    public double getShelfLength() {
        return shelfLength;
    }
    
    public void setShelfHeight(double height) {
        this.shelfHeight = height;
    }
    
    public double getShelfHeight() {
        return shelfHeight;
    }
    
    public void setShelfArea(double shelfarea) {
        this.shelfArea = shelfarea;
    }
    
    public double getShelfArea() {
        return shelfArea;
    }
    
    public void setShelfVolume(double shelfvolume) {
        this.shelfVolume = shelfvolume;
    }
    
    public double getShelfVolume() {
        return shelfVolume;
    }

    public double calculateEmissions() {
        
        /**
         * The area that the shelf base comprises is the area of the shelf less
         * the area between the shelving corners.
         * 
         * The average dimension for the structural components found was 
         * 0.08m by 0.08m (0.0064m^2).
         * 
         * Thus the area of shelf that the base covers is the area of the shelving
         * unit less the area of the structural components.
         */
        
        /**
         * The volume that the content comprises on the shelf is the total volume
         * of the shelving unit, less the volume consumed by the structure, less
         * the volume of the base of the shelf.
         */
        
        double contentEmissions = 0.0;
        double shelfBaseEmissions = 0.0;
        double shelfStructureEmissions = 0.0;
        double shelfBaseArea = ((shelfLength - 0.16) * (shelfWidth - 0.16));
        double shelfContentVolume = shelfBaseArea * (shelfHeight - (shelfLevels * 0.08));

        /**
         * The following calculations differentiate emissions based on type of
         * shelving (shelfType and subType).
         */
        
        /**
         * Differentiate emissions based on type of shelving to be added.
         * 
         * Calculations are written as follows:
         * 
         * (Volume of Content) * (Percent of Volume Used) * (Density of Material)
         *      * (Emissions Factor of Material) = Emissions from shelf contents
         */
        
        //Food...
        if (shelfSubType.equals(ShelfSubType.ALCOHOL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1191.67 * 0.489;
        } else if (shelfSubType.equals(ShelfSubType.CANNED)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1000 * 0.2;
        } else if (shelfSubType.equals(ShelfSubType.DAIRY)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 947.526 * 2.244;
        } else if (shelfSubType.equals(ShelfSubType.GRAINS)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 436.985 * 1.299;
        } else if (shelfSubType.equals(ShelfSubType.MEAT)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 786.672 * 2.281;
        } else if (shelfSubType.equals(ShelfSubType.PRODUCE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 713 * 0.857;
        } else if (shelfSubType.equals(ShelfSubType.DEF_FOOD)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 845.9755 * 1.228;
        
        //Chemicals...  
        } else if (shelfSubType.equals(ShelfSubType.PAINT)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1198 * 3.35;
        } else if (shelfSubType.equals(ShelfSubType.POOL_CHEM)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 920 * 0;
        } else if (shelfSubType.equals(ShelfSubType.ANTIFREEZE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1113 * 2.0;
        } else if (shelfSubType.equals(ShelfSubType.RODENT)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1390 * 2.75;
        } else if (shelfSubType.equals(ShelfSubType.CLEANER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1000 * 0;
        } else if (shelfSubType.equals(ShelfSubType.LAUNDRY)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 885 * 1.69;
        } else if (shelfSubType.equals(ShelfSubType.DEF_CHEM)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1084.3333 * 1.632;
        
        //Plastics...
        } else if(shelfSubType.equals(ShelfSubType.PVC)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1375 * 0.67;
        } else if (shelfSubType.equals(ShelfSubType.PET)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1300 * 1.28;
        } else if (shelfSubType.equals(ShelfSubType.PS)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1050 * 1.64;
        } else if (shelfSubType.equals(ShelfSubType.HDPE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 950 * 1.27;
        } else if (shelfSubType.equals(ShelfSubType.LDPE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 925 * 1.27;
        } else if (shelfSubType.equals(ShelfSubType.PP)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 946 * 1.27;
        } else if (shelfSubType.equals(ShelfSubType.DEF_PLASTIC)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1091 * 1.2333;
            
        //Fuels...
        } else if (shelfSubType.equals(ShelfSubType.NAT_GAS)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 0.8 * 2.8;
        } else if (shelfSubType.equals(ShelfSubType.GASOLINE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 770 * 3.3;
        } else if (shelfSubType.equals(ShelfSubType.BUNKER_CRUDE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 908 * 3.279;
        } else if (shelfSubType.equals(ShelfSubType.BIODIESEL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 875 * 1.232;
        } else if (shelfSubType.equals(ShelfSubType.DIESEL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 832 * 3.242;
        } else if (shelfSubType.equals(ShelfSubType.LPG)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 552.5 * 2.706;
        } else if (shelfSubType.equals(ShelfSubType.DEF_FUEL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 656.3833 * 2.759;
        
        //Wood...    
        } else if (shelfSubType.equals(ShelfSubType.HARD)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 690 * 1.5;
        } else if (shelfSubType.equals(ShelfSubType.HARD_PRESS)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 698 * 1.27;
        } else if (shelfSubType.equals(ShelfSubType.HDF)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 920 * 1.5;    
        } else if (shelfSubType.equals(ShelfSubType.MDF)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 750 * 1.5;
        }else if (shelfSubType.equals(ShelfSubType.PLYWOOD_HARD)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 690 * 1.5;
        } else if (shelfSubType.equals(ShelfSubType.PLYWOOD_SOFT)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 478 * 1.5;
        } else if (shelfSubType.equals(ShelfSubType.SOFT)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 478 * 1.5;    
        } else if (shelfSubType.equals(ShelfSubType.SOFT_PRESS)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 486 * 1.27;
        } else if (shelfSubType.equals(ShelfSubType.DEF_WOOD)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 648.75 * 1.4425;
        
        //Paper...    
        } else if (shelfSubType.equals(ShelfSubType.BATHROOM_PAPER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 375 * 1.5;    
        } else if (shelfSubType.equals(ShelfSubType.CARDBOARD)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 700 * 1.5;
        } else if (shelfSubType.equals(ShelfSubType.COMPUTER_PAPER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 740 * 1.5;
        } else if (shelfSubType.equals(ShelfSubType.NEWSPAPER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 650 * 1.5;
        } else if (shelfSubType.equals(ShelfSubType.DEF_PAPER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 616.25 * 1.5;
            
        //Metal...
        } else if (shelfSubType.equals(ShelfSubType.ALUMINUM)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 2712 * 0;
        } else if (shelfSubType.equals(ShelfSubType.COPPER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 8940 * 0;
        } else if (shelfSubType.equals(ShelfSubType.IRON)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 7874 * 0;
        } else if (shelfSubType.equals(ShelfSubType.STEEL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 7850 * 0.0117;
        } else if (shelfSubType.equals(ShelfSubType.ALLOY)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 2768 * 0.01;
        } else if (shelfSubType.equals(ShelfSubType.DEF_METAL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 6028.8 * 0.0042;
        
        //Textile...
        } else if (shelfSubType.equals(ShelfSubType.COTTON)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1480 * 1.52;
        } else if (shelfSubType.equals(ShelfSubType.CARPET)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 226 * 1.21;        
        } else if (shelfSubType.equals(ShelfSubType.LEATHER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 860 * 0.35;
        } else if (shelfSubType.equals(ShelfSubType.POLYESTER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1300 * 1.28;
        } else if (shelfSubType.equals(ShelfSubType.VINYL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1225 * 0.67;
        } else if (shelfSubType.equals(ShelfSubType.WOOL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1314 * 1.006;
        } else if (shelfSubType.equals(ShelfSubType.DEF_TEXTILE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1067 * 1.006;
        
        //Electronics
        } else if (shelfSubType.equals(ShelfSubType.COMPUTER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 186.915 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.TV)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 132.967 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.LAPTOP)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 1035.55 * 0.419;
        } else if (shelfSubType.equals(ShelfSubType.CRT_MONITOR)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 107.554 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.LCD_MONITOR)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 155.131 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.PERIPHERALS)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 124.5895 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.PRINTER)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 169.342 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.MOBILE_PHONE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 301.359 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.DVD)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 372.55 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.RADIO)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 406.251 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.APPLIANCE)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 178.449 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.TOOL)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 161.21 * 1.8;
        } else if (shelfSubType.equals(ShelfSubType.DEF_ELEC)) {
            contentEmissions = shelfContentVolume * getUsageFraction() * 277.656 * 1.685;
        }
        
        if (shelfBaseType.equals(ShelfBaseType.NONE)) {
            shelfBaseEmissions = 0;
        } else if (shelfBaseType.equals(ShelfBaseType.PALLET)) {
            /**
             * Standard ISO pallet size = 1.016m x 1.219m
             * Average mass for ISO standard pallet = 19.18525 kg
             * Emissions factor for wood = 1.5
             * 
             * Calculations multiply the average mass for a pallet
             * by the number of whole pallets on the shelf,
             * and then by the number of levels of shelving.
             * 
             * The number of whole pallets is determined as the nearest integer
             * of the ratio of the shelf base area to the area of a standard
             * pallet.
            */
            numPallet = (int) Math.round(shelfBaseArea / (1.016 * 1.219));
            shelfBaseEmissions = numPallet * shelfLevels * 19.18525 * 1.5;
        } else if (shelfBaseType.equals(ShelfBaseType.WOOD_BASE)) {
            /**
             * Area of wood on shelf base = shelfBaseArea
             * 
             * Most common 2x6 material is Douglass Fir, Yellow Pine, or Spruce
             * Density of Spruce = 450 kg/m^3
             * Density of Yellow Pine = 420 kg/m^3
             * Density of Douglass Fir = 530 kg/m^3
             * AVG Density = 466.67 kg/m^3
             * Emissions factor for wood = 1.5
             * 
             * Height of shelf base = thickness of 2x6 = 1.5" = 0.0381m
             */
            shelfBaseEmissions = shelfBaseArea * 0.0381 * 466.67 * 1.5;
        } else if (shelfBaseType.equals(ShelfBaseType.FRIDGE)) {
            /**
             * The shelf base emissions for a fridge type shelf is the average
             * weight per unit area of a industrial fridge (248.4 kg/m2) multiplied
             * by the area of the shelf, multiplied by the emissions factor for the
             * primary construction material (steel [0.0117 kgCO2/kg).
             */
            shelfBaseEmissions = 248.4 * shelfArea * 0.0117;
        }
        
        /**
         * The shelf structure emission are the total emissions from the 'skeleton'
         * of the shelving unit.
         * The calculations are made from the mass of steel shelving per unit length.
         * 
         * Volumetric density of steel = 7850 kg/m^3
         * Cross sectional area of shelf structure = 0.000251483m^2
         * 
         * Linear mass density = 7850 * 0.000251483 = 1.97414 kg/m
         * 
         * Emissions factor for steel = 0.0117
         * 
         * 
         * For a fridge type shelf, the structure is ignored, as it is calculated
         * with the shelf base.
         */
        
        if (!shelfBaseType.equals(ShelfBaseType.FRIDGE)) {
            shelfStructureEmissions = 
                    //The 4 corners of the shelving unit
                    ((1.97414 * shelfHeight * 4) + 
                    //The length of shelving * 2 sides of shelving unit * number of levels
                    (1.97414 * shelfLength * 2 * shelfLevels) +
                    //The width of shelving * 2 sides of shelving unit * number of levels
                    (1.97414 * shelfWidth * 2 * shelfLevels)) * .0117;
        } else if (shelfBaseType.equals(ShelfBaseType.FRIDGE)) {
            shelfStructureEmissions = 0.0;
        }
        
        //Multiply the result by the percentage of damage.
        double emissions = (contentEmissions + shelfBaseEmissions + shelfStructureEmissions) * getDamageFraction() * getShelfQuantity();
        return emissions;
        
    }

    public int getDamage() {
        return damage;
    }

    public void setDamage(int damage) {
        this.damage = damage;
    }

    public double getDamageFraction() {
        double damagefrac = damage * 0.01;
        return damagefrac;
    }
    
    public void setAreaUsage(int areausage) {
        this.areausage = areausage;
    }
    
    public int getAreaUsage() {
        return areausage;
    }
    
    public void setHeightUsage(int heightusage) {
        this.heightusage = heightusage;
    }
    
    public int getHeightUsage() {
        return heightusage;
    }
    
    public double getUsageFraction() {
        double usagefrac = areausage * heightusage * 0.01 * 0.01;
        return usagefrac;
    }

    @Override
    public String toString() {
        return shelfType.toString() + " (" + String.format("%.2f", getShelfArea()) + " m^2)";
    }
    
    

}
