/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.visual.content;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.FlowLayout;

import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.border.EmptyBorder;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import javax.swing.border.TitledBorder;
import javax.swing.JComboBox;
import javax.swing.DefaultComboBoxModel;
import sa.shpi.advanced.model.Strings;
import sa.shpi.advanced.model.content.FurnishingList;
import sa.shpi.advanced.model.content.Room;
import sa.shpi.advanced.model.content.RoomType;
import sa.shpi.advanced.model.content.UsedFurnishing;
import sa.shpi.advanced.visual.AdvancedMainForm;

import javax.swing.JScrollPane;
import javax.swing.JList;
import javax.swing.border.EtchedBorder;
import javax.swing.SwingConstants;
import java.awt.event.ActionEvent;
import java.awt.event.FocusListener;
import java.awt.event.FocusEvent;
import java.awt.Dialog.ModalityType;
import java.awt.Window.Type;
import javax.swing.Box;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.event.ChangeEvent;
import sa.shpi.advanced.model.Warehouse;

/**
 * Form for a room that allows a user to add multiple furniture items to a room.
 * Also contains logical steps to validate that the room area does not exceed the
 * structure area, and that if a room uses a preset default, that it does not
 * also use individual furnishing items.
 *
 * @author Kyle
 *
 */
public class RoomDetailForm extends JDialog {

    private static final long serialVersionUID = 1L;

    private final JPanel contentPanel = new JPanel();
    private JList furnishingList = new JList();
    private JLabel damageLabel = new JLabel("100%");
    private JSlider damageSlider = new JSlider();
    private final JPanel panel1 = new JPanel();
    private JTextField roomAreaText = new JTextField(null);
    private final JPanel panel2 = new JPanel();
    private final JPanel panel3 = new JPanel();
    private JComboBox roomTypeComboBox = new JComboBox();
    private JButton addButton = new JButton(Strings.ADD.toString());
    private final JPanel panel4 = new JPanel();
    private JTextField roomQuantity = new JTextField();

    String doubleregex = "^[1-9][0-9]*[.][0-9]*$";
    String intregex = "^[1-9][0-9]*$";
    
    private Room room;
    Warehouse ware;

    private AdvancedMainForm parent;

    /**
     * Create the dialog.
     * 
     * @param parent
     */
    public RoomDetailForm(AdvancedMainForm parent) {
        super(parent.getFrame());

        //Creat a new instance
        room = new Room();
        //Set the initial values.
        room.setRoomType(RoomType.MAIN_OFFICE);
        room.setRoomArea(8.7);
        roomAreaText.setText("8.7");
        room.setRoomQuantity(1);
        roomQuantity.setText("1");
        

        setTitle(Strings.ROOM.toString());
        setType(Type.UTILITY);
        setResizable(false);
        setModalityType(ModalityType.APPLICATION_MODAL);
        setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
        this.parent = parent;

        setBounds(100, 100, 380, 575);
        getContentPane().setLayout(new BorderLayout());
        contentPanel.setBorder(new EmptyBorder(5, 5, 5, 5));
        getContentPane().add(contentPanel, BorderLayout.CENTER);
        GridBagLayout gbl_contentPanel = new GridBagLayout();
        gbl_contentPanel.columnWidths = new int[]{0, 0};
        gbl_contentPanel.rowHeights = new int[]{0, 0, 0, 0};
        gbl_contentPanel.columnWeights = new double[]{1.0, Double.MIN_VALUE};
        gbl_contentPanel.rowWeights = new double[]{0.0, 1.0, 0.0,
            Double.MIN_VALUE};
        contentPanel.setLayout(gbl_contentPanel);
        {
            {
                JPanel panel = new JPanel();
                panel.setBorder(new TitledBorder(null,
                    Strings.ROOM_TYPE.toString(), TitledBorder.LEADING,
                    TitledBorder.TOP, null, null));
                GridBagConstraints gbc_panel = new GridBagConstraints();
                gbc_panel.insets = new Insets(0, 0, 5, 0);
                gbc_panel.fill = GridBagConstraints.BOTH;
                gbc_panel.gridx = 0;
                gbc_panel.gridy = 0;
                contentPanel.add(panel, gbc_panel);
                GridBagLayout gbl_panel = new GridBagLayout();
                gbl_panel.columnWidths = new int[]{0, 0};
                gbl_panel.rowHeights = new int[]{0, 0};
                gbl_panel.columnWeights = new double[]{1.0, Double.MIN_VALUE};
                gbl_panel.rowWeights = new double[]{0.0, Double.MIN_VALUE};
                panel.setLayout(gbl_panel);
                
                {
                    //Combo box to input type of room.
                    roomTypeComboBox.addActionListener((ActionEvent e) -> {
                        //Set RoomType to the selection of the combo box.
                        room.setRoomType((RoomType) roomTypeComboBox.getSelectedItem());
                        if (room.getRoomType().equals(RoomType.BATHROOM)) {
                            roomAreaText.setText("2.16");
                            room.setRoomArea(2.56);
                        } else if (room.getRoomType().equals(RoomType.BREAK_AREA)) {
                            roomAreaText.setText("10.0");
                            room.setRoomArea(10.0);
                        } else if (room.getRoomType().equals(RoomType.CONFERENCE)) {
                            roomAreaText.setText("15.0");
                            room.setRoomArea(15.0);
                        } else if (room.getRoomType().equals(RoomType.CUBICLE)) {
                            roomAreaText.setText("2.755");
                            room.setRoomArea(2.755);
                        } else if (room.getRoomType().equals(RoomType.MAIN_OFFICE)) {
                            roomAreaText.setText("8.7");
                            room.setRoomArea(8.7);
                        }
                    });

                    roomTypeComboBox.setModel(new DefaultComboBoxModel(RoomType.values()));
                    GridBagConstraints gbc_roomTypeComboBox = new GridBagConstraints();
                    gbc_roomTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                    gbc_roomTypeComboBox.gridx = 0;
                    gbc_roomTypeComboBox.gridy = 0;
                    panel.add(roomTypeComboBox, gbc_roomTypeComboBox);
                }
                {
                    //Help dialog for room type.
                    ImageIcon roomTypeIcon = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                    JButton roomTypeHelp = new JButton("?");
                    roomTypeHelp.addActionListener((ActionEvent e) -> {
                        JOptionPane.showMessageDialog(null, "Selección del tipo de área para añadir a la bodega.",
                                Strings.ROOM_TYPE.toString(), JOptionPane.INFORMATION_MESSAGE, roomTypeIcon);
                    });
                    GridBagConstraints gbc_roomTypeHelp = new GridBagConstraints();
                    gbc_roomTypeHelp.anchor = GridBagConstraints.CENTER;
                    gbc_roomTypeHelp.gridx = 1;
                    panel.add(roomTypeHelp, gbc_roomTypeHelp);
                }
            }
            {
                panel1.setBorder(new TitledBorder(Strings.ROOM_AREA.toString()));
                GridBagConstraints gbc_panel1 = new GridBagConstraints();
                gbc_panel1.fill = GridBagConstraints.HORIZONTAL;
                gbc_panel1.insets = new Insets(0, 0, 5, 0);
                gbc_panel1.gridx = 0;
                gbc_panel1.gridy = 1;
                contentPanel.add(panel1, gbc_panel1);
                GridBagLayout gbl_panel1 = new GridBagLayout();
                gbl_panel1.columnWidths = new int[]{0, 0, 0};
                gbl_panel1.rowHeights = new int[]{0, 0, 0};
                gbl_panel1.columnWeights = new double[]{0.5, 0.5, 0.5, Double.MIN_VALUE};
                gbl_panel1.rowWeights = new double[]{0.0, 0.0, Double.MIN_VALUE};
                panel1.setLayout(gbl_panel1);

                {
                    Component verticalStrut = Box.createVerticalStrut(10);
                    GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                    gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                    gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                    gbc_verticalStrut.gridx = 0;
                    gbc_verticalStrut.gridy = 0;
                    panel1.add(verticalStrut, gbc_verticalStrut);
                }
                {
                    //Text input field for area of room.
                    roomAreaText.setHorizontalAlignment(SwingConstants.CENTER);
                    roomAreaText.addFocusListener(new FocusListener() {
                        /*
                         * The FocusListener highlights all text in the quantity field
                         * and enables the area field on entry.  The listener 
                         * assigns a value to roomarea when the user
                         * exits the text entry field.
                         */
                        @Override
                        public void focusGained(FocusEvent e) {
                            roomAreaText.selectAll();
                        }

                        @Override
                        public void focusLost(FocusEvent e) {
                            //Validate input
                            String value = roomAreaText.getText();
                            if (value.matches(intregex)) {
                                room.setRoomArea(Double.parseDouble(value + ".0"));
                                roomAreaText.setText(value + ".0");
                            } else if (roomAreaText.getText().matches(doubleregex)){
                                room.setRoomArea(Double.parseDouble(value));
                            } else {
                                JOptionPane.showMessageDialog(rootPane, Strings.ERROR_BASE);
                                room.setRoomArea(1.0);
                                roomAreaText.setText("1.0");
                            }
                        }
                    });

                    GridBagConstraints gbc_roomAreaText = new GridBagConstraints();
                    gbc_roomAreaText.anchor = GridBagConstraints.CENTER;
                    gbc_roomAreaText.ipadx = 100;
                    gbc_roomAreaText.gridx = 1;
                    gbc_roomAreaText.gridy = 1;
                    panel1.add(roomAreaText, gbc_roomAreaText);
                    roomAreaText.setColumns(10);

                }
                {
                    //Unit label for room area.
                    JLabel roomAreaLabel = new JLabel(" m^2");
                    GridBagConstraints gbc_roomAreaLabel = new GridBagConstraints();
                    gbc_roomAreaLabel.anchor = GridBagConstraints.LINE_START;
                    gbc_roomAreaLabel.insets = new Insets(0, 0, 0, 0);
                    gbc_roomAreaLabel.gridx = 2;
                    gbc_roomAreaLabel.gridy = 1;
                    panel1.add(roomAreaLabel, gbc_roomAreaLabel);
                }
                {
                    Component verticalStrut = Box.createVerticalStrut(10);
                    GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                    gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                    gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                    gbc_verticalStrut.gridx = 0;
                    gbc_verticalStrut.gridy = 2;
                    panel1.add(verticalStrut, gbc_verticalStrut);
                }
                {
                    //Help dialog for room area.
                    ImageIcon roomAreaIcon = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                    JButton roomAreaHelp = new JButton("?");
                    roomAreaHelp.addActionListener((ActionEvent e) -> {
                        JOptionPane.showMessageDialog(null, "El área, en metros cuadrados (m^2).\nLa área es establece en la estandar por la tipo de área que es seleccionada.",
                                Strings.ROOM_AREA.toString(), JOptionPane.INFORMATION_MESSAGE, roomAreaIcon);
                    });
                    GridBagConstraints gbc_roomAreaHelp = new GridBagConstraints();
                    gbc_roomAreaHelp.anchor = GridBagConstraints.CENTER;
                    gbc_roomAreaHelp.gridx = 3;
                    gbc_roomAreaHelp.gridy = 1;
                    panel1.add(roomAreaHelp, gbc_roomAreaHelp);
                }

            }
            {
                panel4.setBorder(new TitledBorder(Strings.ROOM_QUANTITY.toString()));
                GridBagConstraints gbc_panel4 = new GridBagConstraints();
                gbc_panel4.insets = new Insets(0, 0, 5, 0);
                gbc_panel4.fill = GridBagConstraints.BOTH;
                gbc_panel4.gridx = 0;
                gbc_panel4.gridy = 2;
                contentPanel.add(panel4, gbc_panel4);
                GridBagLayout gbl_panel4 = new GridBagLayout();
                gbl_panel4.columnWidths = new int[]{0, 0};
                gbl_panel4.rowHeights = new int[]{0, 0, 0};
                gbl_panel4.columnWeights = new double[]{1.0, Double.MIN_VALUE};
                gbl_panel4.rowWeights = new double[]{1.0, 0.0, Double.MIN_VALUE};
                panel4.setLayout(gbl_panel4);
            
                {
                    Component verticalStrut = Box.createVerticalStrut(10);
                    GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                    gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                    gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                    gbc_verticalStrut.gridx = 0;
                    gbc_verticalStrut.gridy = 0;
                    panel4.add(verticalStrut, gbc_verticalStrut);
                }
                {
                    //Quantity field for number of rooms to be added.
                    roomQuantity.addFocusListener(new FocusListener() {
                        @Override
                        public void focusGained(FocusEvent e) {
                            roomQuantity.selectAll();
                        }
                        @Override
                        public void focusLost(FocusEvent e) {
                            String value = roomQuantity.getText();
                            if (value.matches(intregex)) {
                                room.setRoomQuantity(Integer.parseInt(roomQuantity.getText()));
                            } else if (value.matches(doubleregex)) {
                                room.setRoomQuantity((int) Double.parseDouble(roomQuantity.getText()));
                                roomQuantity.setText(String.valueOf(room.getRoomQuantity()));
                            }
                        }
                    });
                    GridBagConstraints gbc_roomQuantity = new GridBagConstraints();
                    gbc_roomQuantity.anchor = GridBagConstraints.CENTER;
                    gbc_roomQuantity.fill = GridBagConstraints.HORIZONTAL;
                    gbc_roomQuantity.gridx = 0;
                    gbc_roomQuantity.gridy = 1;
                    roomQuantity.setColumns(10);
                    roomQuantity.setHorizontalAlignment(SwingConstants.CENTER);
                    panel4.add(roomQuantity, gbc_roomQuantity);
                }
                {
                    //Help dialog for room quantity.
                    ImageIcon roomQuantityIcon = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                    JButton roomQuantityHelp = new JButton("?");
                    roomQuantityHelp.addActionListener((ActionEvent e) -> {
                        JOptionPane.showMessageDialog(null, "El número de áreas idénticas para añadir a la bodega.",
                                Strings.ROOM_QUANTITY.toString(), JOptionPane.INFORMATION_MESSAGE, roomQuantityIcon);
                    });
                    GridBagConstraints gbc_roomQuantityHelp = new GridBagConstraints();
                    gbc_roomQuantityHelp.anchor = GridBagConstraints.CENTER;
                    gbc_roomQuantityHelp.gridx = 1;
                    gbc_roomQuantityHelp.gridy = 1;
                    panel4.add(roomQuantityHelp, gbc_roomQuantityHelp);
                }
                {
                    Component verticalStrut = Box.createVerticalStrut(10);
                    GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                    gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                    gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                    gbc_verticalStrut.gridx = 0;
                    gbc_verticalStrut.gridy = 2;
                    panel4.add(verticalStrut, gbc_verticalStrut);
                }
            }
            
                {
                panel2.setBorder(new TitledBorder(new EtchedBorder(
                        EtchedBorder.LOWERED, null, null), Strings.FURNISHING
                        .toString(), TitledBorder.LEADING, TitledBorder.TOP, null,
                        null));
                GridBagConstraints gbc_panel2 = new GridBagConstraints();
                gbc_panel2.insets = new Insets(0, 0, 5, 0);
                gbc_panel2.fill = GridBagConstraints.BOTH;
                gbc_panel2.gridx = 0;
                gbc_panel2.gridy = 3;
                contentPanel.add(panel2, gbc_panel2);
                GridBagLayout gbl_panel2 = new GridBagLayout();
                gbl_panel2.columnWidths = new int[]{0, 0};
                gbl_panel2.rowHeights = new int[]{0, 0, 0};
                gbl_panel2.columnWeights = new double[]{1.0, Double.MIN_VALUE};
                gbl_panel2.rowWeights = new double[]{1.0, 0.0, Double.MIN_VALUE};
                panel2.setLayout(gbl_panel2);
                {
                    //Scroll pane to display furnishing list.
                    JScrollPane scrollPane = new JScrollPane();
                    GridBagConstraints gbc_scrollPane = new GridBagConstraints();
                    gbc_scrollPane.insets = new Insets(0, 0, 5, 0);
                    gbc_scrollPane.fill = GridBagConstraints.BOTH;
                    gbc_scrollPane.gridx = 0;
                    gbc_scrollPane.gridy = 0;
                    panel2.add(scrollPane, gbc_scrollPane);
                    {
                        furnishingList = new JList();
                        scrollPane.setViewportView(furnishingList);
                    }
                }
                {
                    //Button to add furnishings to list.
                    JButton newItemButton = new JButton(Strings.ADD.toString()
                            + " " + Strings.FURNITURE_ITEM.toString() + "...");
                    newItemButton.addActionListener((ActionEvent e) -> {
                        FurnishingDetailForm furnishingForm = new FurnishingDetailForm(
                                RoomDetailForm.this);
                    });
                    newItemButton.setHorizontalAlignment(SwingConstants.LEFT);
                    GridBagConstraints gbc_newItemButton = new GridBagConstraints();
                    gbc_newItemButton.anchor = GridBagConstraints.WEST;
                    gbc_newItemButton.gridx = 0;
                    gbc_newItemButton.gridy = 1;
                    panel2.add(newItemButton, gbc_newItemButton);
                }
                {
                    //Help dialog for room furnishings.
                    ImageIcon roomStuffIcon = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                    JButton roomStuffHelp = new JButton("?");
                    roomStuffHelp.addActionListener((ActionEvent e) -> {
                        JOptionPane.showMessageDialog(null, "Los meubles son objetos que se encuentran típicamente"
                                + " en el tipo de área seleccionado.\nHay dos opcionnes para añaden muebles:\n"
                                + "1) Seleccionar cada uno de los muebles por separado\n"
                                + "2) Elijir 'Área Estandar' que usa una carga media de este tipo de área",
                                Strings.FURNISHING.toString(), JOptionPane.INFORMATION_MESSAGE, roomStuffIcon);
                    });
                    GridBagConstraints gbc_roomStuffHelp = new GridBagConstraints();
                    gbc_roomStuffHelp.anchor = GridBagConstraints.LINE_END;
                    gbc_roomStuffHelp.gridx = 0;
                    gbc_roomStuffHelp.gridy = 1;
                    panel2.add(roomStuffHelp, gbc_roomStuffHelp);
                }
                }
            {
                panel3.setBorder(new TitledBorder(new EtchedBorder(
                        EtchedBorder.LOWERED, null, null), Strings.DAMAGE
                        .toString(), TitledBorder.LEADING, TitledBorder.TOP, null,
                        null));
                GridBagConstraints gbc_panel3 = new GridBagConstraints();
                gbc_panel3.fill = GridBagConstraints.BOTH;
                gbc_panel3.gridx = 0;
                gbc_panel3.gridy = 4;
                contentPanel.add(panel3, gbc_panel3);
                GridBagLayout gbl_panel3 = new GridBagLayout();
                panel3.setLayout(gbl_panel3);
                {
                    //Text label for the damage slider.
                    JLabel lblNewLabel = new JLabel(
                            Strings.PERCENT_DAMAGE.toString() + ":");
                    GridBagConstraints gbc_lblNewLabel = new GridBagConstraints();
                    gbc_lblNewLabel.anchor = GridBagConstraints.CENTER;
                    gbc_lblNewLabel.gridx = 0;
                    gbc_lblNewLabel.gridy = 0;
                    panel3.add(lblNewLabel, gbc_lblNewLabel);
                }
                {

                    GridBagConstraints gbc_damageLabel = new GridBagConstraints();
                    gbc_damageLabel.anchor = GridBagConstraints.CENTER;
                    gbc_damageLabel.gridx = 1;
                    gbc_damageLabel.gridy = 0;
                    panel3.add(damageLabel, gbc_damageLabel);
                }
                {
                    //Slider to input percentage of room damaged.
                    damageSlider.addChangeListener((ChangeEvent arg0) -> {
                        damageLabel.setText(String.valueOf(damageSlider
                                .getValue()) + "%");
                        room.setDamage(damageSlider.getValue());
                    });
                    damageSlider.setValue(100);
                    damageSlider.setMajorTickSpacing(10);
                    damageSlider.setPaintTicks(true);
                    damageSlider.setPaintLabels(true);
                    GridBagConstraints gbc_damageSlider = new GridBagConstraints();
                    gbc_damageSlider.anchor = GridBagConstraints.CENTER;
                    gbc_damageSlider.gridwidth = 2;
                    gbc_damageSlider.gridx = 0;
                    gbc_damageSlider.gridy = 1;
                    panel3.add(damageSlider, gbc_damageSlider);
                }
                {
                    Component box = Box.createHorizontalStrut(50);
                    GridBagConstraints gbc_box = new GridBagConstraints();
                    gbc_box.anchor = GridBagConstraints.CENTER;
                    gbc_box.gridheight = 2;
                    gbc_box.gridy = 0;
                    gbc_box.gridx = 2;
                    panel3.add(box, gbc_box);
                }
                {
                    //Help dialog for room damage slider.
                    ImageIcon roomDamageIcon = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                    JButton roomDamageHelp = new JButton("?");
                    roomDamageHelp.addActionListener((ActionEvent e) -> {
                        JOptionPane.showMessageDialog(null, "El porcentaje del área que fue dañado.",
                                Strings.DAMAGE.toString(), JOptionPane.INFORMATION_MESSAGE, roomDamageIcon);
                    });
                    GridBagConstraints gbc_roomDamageHelp = new GridBagConstraints();
                    gbc_roomDamageHelp.anchor = GridBagConstraints.LINE_END;
                    gbc_roomDamageHelp.gridx = 3;
                    gbc_roomDamageHelp.gridy = 0;
                    gbc_roomDamageHelp.gridheight = 2;
                    panel3.add(roomDamageHelp, gbc_roomDamageHelp);
                }
            }
            {
                JPanel buttonPane = new JPanel();
                buttonPane.setLayout(new FlowLayout(FlowLayout.RIGHT));
                getContentPane().add(buttonPane, BorderLayout.SOUTH);
                {
                    JButton cancelButton = new JButton(Strings.CANCEL.toString());
                    cancelButton.addActionListener((ActionEvent e) -> {
                        setVisible(false);
                        dispose();
                    });
                    buttonPane.add(cancelButton);
                }
                {
                    //Add button: adds room to structure.
                    addButton.addActionListener((ActionEvent e) -> {
                        ImageIcon imageicon = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                        if ((ware.getTotalRoomArea() + ((Double.parseDouble(roomAreaText.getText())) 
                                    * Integer.parseInt(roomQuantity.getText()))) > 
                                    Warehouse.getAreaTotal()) {
                                    JOptionPane.showMessageDialog(null, Strings.ROOM_AREA_BIGGER, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, imageicon);
                                    setVisible(true);
                            }
                        else  if (room.getFurnishingList().isEmpty()) {
                            JOptionPane.showMessageDialog(null, Strings.FURN_LIST_EMPTY, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, imageicon);
                        } else {
                            int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, imageicon);
                            if (response == JOptionPane.CANCEL_OPTION) {
                                setVisible(true);
                            } else if (response == JOptionPane.OK_OPTION) {
                                ware.addTotalRoomArea(Double.parseDouble(roomAreaText.getText())
                                * Integer.parseInt(roomQuantity.getText()));
                                getParentForm().addRoom(room);
                                dispose();
                                setVisible(false);
                            }
                        }
                    });
                buttonPane.add(addButton);
                rootPane.setDefaultButton(addButton);
                }
                setVisible(true);
            }
        }
    }
    
    
    

    public AdvancedMainForm getParentForm() {
        return parent;
    }

    public void addFurnitureItem(UsedFurnishing uFurnishing) {
        //Get furnishing item from the furnishing detail form and add it to the room.
        room.addFurnishing(uFurnishing);

        DefaultListModel<UsedFurnishing> defaultListModel = new DefaultListModel<UsedFurnishing>();
        FurnishingList roomFurnishingList = room.getFurnishingList();
        for (int count = 0; count < roomFurnishingList.size(); count++) {
            defaultListModel.addElement(roomFurnishingList.get(count));
        }

        furnishingList.setModel(defaultListModel);

    }

}
