/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.model.structure;

import sa.shpi.advanced.model.EmissionsItem;
import sa.shpi.advanced.model.Industrial;
import sa.shpi.advanced.model.Library;

/**
 * Dynamic material library with presets to add to structural components. Also
 * contains components that can be used as default structure items.
 * 
 * Specific to flooring.
 *
 * @author Kyle
 *
 */
public class FlooringMaterialsLibrary extends MaterialsLibrary {

    public FlooringMaterialsLibrary() {

        /**
         * Emissions items are written in the format: ("item name", emissions
         * factor, mass per unit area)
         */
        lib.clear();
        lib.add(new EmissionsItem("Concreto", 0.00, 0.00));
        lib.add(new EmissionsItem("Acero", 0.0117, (((.00159 * Industrial.getAreaTotal())
                    * 7850) / Industrial.getAreaTotal())));
    }

    @Override
    public String getUnits() {
        return "kg/m^2";
    }

}
