/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.visual;

import javax.swing.JPanel;
import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.GridBagLayout;
import javax.swing.JLabel;
import java.awt.GridBagConstraints;
import javax.swing.JTextField;
import java.awt.Insets;
import javax.swing.JComboBox;

import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.SwingConstants;
import javax.swing.JButton;
import java.awt.Component;
import javax.swing.Box;
import javax.swing.DefaultComboBoxModel;

import sa.shpi.advanced.model.Strings;
import sa.shpi.advanced.model.Industrial;
import sa.shpi.advanced.model.IndustrialType;
import sa.shpi.advanced.model.content.Room;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Dialog.ModalityType;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import javax.swing.BorderFactory;
import javax.swing.ImageIcon;

/**
 * When creating a new building, this form allows the user to input the total
 * area and area affected, as well as the type of industrial building.
 *
 * @author Kyle
 *
 */
public class IndustrialDetailForm extends JDialog {

    private static final long serialVersionUID = 1L;
    
    private ImageIcon shpi = new ImageIcon(IndustrialDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));

    private AdvancedMainForm parent;
    private JTextField totalAreaTextField;
    private JTextField areaBurnedTextField;
    private JComboBox industrialTypeComboBox;
    private JButton industrialTypeHelp = new JButton ("?");
    
    Room room;
    
    //Validation strings for text input.
    private String doubleregex = "^[0-9]*[.][0-9]*$";
    private String intregex = "^[1-9][0-9]*$";

    public IndustrialDetailForm(AdvancedMainForm parent) {
        super(parent.getFrame());
        this.parent = parent;
        initialize();
    }

    /**
     * Initialize the contents of the frame.
     */
    private void initialize() {
        setTitle(Strings.NEW_INDUSTRIAL.toString());
        setLocationRelativeTo(parent.getFrame());
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);
        setModalityType(ModalityType.APPLICATION_MODAL);
        setBounds(100, 100, 350, 300);
        setResizable(false);

        JPanel panel = new JPanel();
        getContentPane().add(panel, BorderLayout.CENTER);
        GridBagLayout gbl_panel = new GridBagLayout();
        panel.setLayout(gbl_panel);
        
        JPanel areaPanel = new JPanel();
        areaPanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(Color.BLACK), Strings.AREA.toString()));
        GridBagConstraints gbc_areaPanel = new GridBagConstraints();
        gbc_areaPanel.anchor = GridBagConstraints.CENTER;
        gbc_areaPanel.fill = GridBagConstraints.BOTH;
        gbc_areaPanel.gridy = 0;
        gbc_areaPanel.gridwidth = 2;
        GridBagLayout gbl_areaPanel = new GridBagLayout();
        areaPanel.setLayout(gbl_areaPanel);
        panel.add(areaPanel, gbc_areaPanel);
        
        JLabel lblNewLabel = new JLabel(Strings.AREA_TOTAL.toString());
        GridBagConstraints gbc_lblNewLabel = new GridBagConstraints();
        gbc_lblNewLabel.anchor = GridBagConstraints.WEST;
        gbc_lblNewLabel.gridy = 1;
        areaPanel.add(lblNewLabel, gbc_lblNewLabel);

        totalAreaTextField = new JTextField();
        totalAreaTextField.setHorizontalAlignment(SwingConstants.RIGHT);
        totalAreaTextField.setText("1.00");
        totalAreaTextField.addFocusListener(new FocusListener() {

            @Override
            public void focusGained(FocusEvent e) {
                totalAreaTextField.selectAll();
            }

            @Override
            public void focusLost(FocusEvent e) {
                String input = totalAreaTextField.getText();
                if (input.matches(intregex)) {
                    totalAreaTextField.setText(input + ".00");
                } else if (input.matches(doubleregex)) {
                    totalAreaTextField.setText(String.format("%.2f", Double.parseDouble(input)));
                } else {
                    totalAreaTextField.setText("1.00");
                    JOptionPane.showMessageDialog(null, Strings.ERROR_BASE.toString() + " " + Strings.AREA_TOTAL, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                }
            }
        
        });
        GridBagConstraints gbc_totalAreaTextField = new GridBagConstraints();
        gbc_totalAreaTextField.fill = GridBagConstraints.HORIZONTAL;
        gbc_totalAreaTextField.gridy = 2;
        areaPanel.add(totalAreaTextField, gbc_totalAreaTextField);
        totalAreaTextField.setColumns(10);

        JLabel lblNewLabel_1 = new JLabel(Strings.AREA_BURNED.toString());
        GridBagConstraints gbc_lblNewLabel_1 = new GridBagConstraints();
        gbc_lblNewLabel_1.anchor = GridBagConstraints.ABOVE_BASELINE_LEADING;
        gbc_lblNewLabel_1.gridy = 4;
        areaPanel.add(lblNewLabel_1, gbc_lblNewLabel_1);

        areaBurnedTextField = new JTextField();
        areaBurnedTextField.setHorizontalAlignment(SwingConstants.RIGHT);
        areaBurnedTextField.setText("1.00");
        areaBurnedTextField.addFocusListener(new FocusListener() {
            @Override
            public void focusGained(FocusEvent e) {
                areaBurnedTextField.selectAll();
            }
            
            @Override
            public void focusLost(FocusEvent e) {
                String input = areaBurnedTextField.getText();
                if (input.matches(intregex)) {
                    areaBurnedTextField.setText(input + ".00");
                } else if (input.matches(doubleregex)) {
                    areaBurnedTextField.setText(String.format("%.2f", Double.parseDouble(input)));
                } else {
                    areaBurnedTextField.setText("1.00");
                    JOptionPane.showMessageDialog(null, Strings.ERROR_BASE.toString() + Strings.AREA_BURNED, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                }
            }
        });
        GridBagConstraints gbc_areaBurnedTextField = new GridBagConstraints();
        gbc_areaBurnedTextField.fill = GridBagConstraints.HORIZONTAL;
        gbc_areaBurnedTextField.gridy = 5;
        areaPanel.add(areaBurnedTextField, gbc_areaBurnedTextField);
        areaBurnedTextField.setColumns(10);
        
        Component box = Box.createVerticalStrut(20);
        GridBagConstraints gbc_box = new GridBagConstraints();
        gbc_box.gridy = 3;
        panel.add(box, gbc_box);

        JPanel typePanel = new JPanel();
        typePanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createLineBorder(Color.BLACK), Strings.IND_TYPE.toString()));
        GridBagConstraints gbc_typePanel = new GridBagConstraints();
        gbc_typePanel.anchor = GridBagConstraints.CENTER;
        gbc_typePanel.gridy = 4;
        gbc_typePanel.gridwidth = 2;
        GridBagLayout gbl_typePanel = new GridBagLayout();
        typePanel.setLayout(gbl_typePanel);
        panel.add(typePanel, gbc_typePanel);
        
        industrialTypeComboBox = new JComboBox();
        industrialTypeComboBox.setModel(new DefaultComboBoxModel(IndustrialType.values()));
        industrialTypeComboBox.setSelectedItem(null);
        GridBagConstraints gbc_industrialTypeComboBox = new GridBagConstraints();
        gbc_industrialTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
        gbc_industrialTypeComboBox.anchor = GridBagConstraints.CENTER;
        gbc_industrialTypeComboBox.gridy = 0;
        typePanel.add(industrialTypeComboBox, gbc_industrialTypeComboBox);
        
        industrialTypeHelp.addActionListener((ActionEvent e) -> {
            JOptionPane.showMessageDialog(null, "El producto de la industria.", Strings.IND_TYPE.toString(),
                    JOptionPane.INFORMATION_MESSAGE, shpi);
        });
        GridBagConstraints gbc_industrialTypeHelp = new GridBagConstraints();
        gbc_industrialTypeHelp.anchor = GridBagConstraints.LINE_END;
        gbc_industrialTypeHelp.gridy = 0;
        typePanel.add(industrialTypeHelp, gbc_industrialTypeHelp);
        
        Component box1 = Box.createVerticalStrut(20);
        GridBagConstraints gbc_box1 = new GridBagConstraints();
        gbc_box1.gridy = 5;
        panel.add(box1, gbc_box1);

        JButton cancelButton = new JButton(Strings.CANCEL.toString());
        cancelButton.addActionListener((ActionEvent e) -> {
            setVisible(false);
            dispose();
        });
        GridBagConstraints gbc_cancelButton = new GridBagConstraints();
        gbc_cancelButton.gridy = 6;
        gbc_cancelButton.gridx = 1;
        gbc_cancelButton.anchor = GridBagConstraints.CENTER;
        panel.add(cancelButton, gbc_cancelButton);

        JButton addButton = new JButton(Strings.ADD.toString());
        addButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent arg0) {
                Industrial ind = new Industrial();
                if (industrialTypeComboBox.getSelectedItem() == null) {
                    JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.IND_TYPE, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                    setVisible(true);
                } else if (Double.parseDouble(areaBurnedTextField.getText()) > Double.parseDouble(totalAreaTextField.getText())) {
                    JOptionPane.showMessageDialog(null, Strings.ERROR_BURNED_BIGGER, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                    setVisible(true);
                } else {
                    int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, shpi);
                    if (response == JOptionPane.CANCEL_OPTION) {
                        setVisible(true);
                    } else  if (response == JOptionPane.OK_OPTION) {
                        ind.setAreaTotal(Double.parseDouble(totalAreaTextField.getText()));
                        ind.setAreaBurned(Double.parseDouble(areaBurnedTextField.getText()));
                        ind.setIndustrialType((IndustrialType) industrialTypeComboBox.getSelectedItem());
                        ind.initializeroomlibrary();
                        parent.addIndustrialItem(ind);
                        setVisible(false);
                        dispose();
                    }
                }
            }
        });
        //Sets the default highlighted button:
        getRootPane().setDefaultButton(addButton);

        GridBagConstraints gbc_addButton = new GridBagConstraints();
        gbc_addButton.gridy = 6;
        gbc_addButton.gridx = 1;
        gbc_addButton.anchor = GridBagConstraints.LINE_END;
        panel.add(addButton, gbc_addButton);

        this.setVisible(true);

    }

}
