/**
 * *****************************************************************************
 * This application has been revised as a part of an Interactive Qualifying
 * Project for Worcester Polytechnic Institute and our sponsor, SHPI Ingenieria.
 *
 * Revision Developer: Kyle Fortin
 *
 * Revision Authors: Stella Banou, Devin Duarte, Kyle Fortin, Taylor Llodra
 *
 * The application is based on work completed by a previous IQP team from WPI.
 *
 * Original Developer: Tyler Stone
 *
 * Original Authors: Alexandra Hardin, Eric Schattschneider, Tyler Stone,
 * Kristina Walker
 * ****************************************************************************
 */
package sa.shpi.advanced.visual.content;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dialog.ModalityType;
import java.awt.FlowLayout;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.Window.Type;
import java.awt.event.ActionEvent;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.math.BigDecimal;
import java.math.RoundingMode;

import javax.swing.Box;
import javax.swing.DefaultComboBoxModel;
import javax.swing.DefaultListModel;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JScrollPane;
import javax.swing.JSlider;
import javax.swing.JTextField;
import javax.swing.SwingConstants;
import javax.swing.border.EmptyBorder;
import javax.swing.border.EtchedBorder;
import javax.swing.border.TitledBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import sa.shpi.advanced.model.Industrial;
import sa.shpi.advanced.model.IndustrialType;
import sa.shpi.advanced.model.Strings;
import sa.shpi.advanced.model.content.ChemFinGoodType;
import sa.shpi.advanced.model.content.ChemRawMatType;
import sa.shpi.advanced.model.content.ConstFinGoodType;
import sa.shpi.advanced.model.content.ConstRawMatType;
import sa.shpi.advanced.model.content.FinGoodStorageType;
import sa.shpi.advanced.model.content.FinGoodType;
import sa.shpi.advanced.model.content.FoodFinGoodType;
import sa.shpi.advanced.model.content.FoodRawMatType;
import sa.shpi.advanced.model.content.FuelType;
import sa.shpi.advanced.model.content.FurnishingList;
import sa.shpi.advanced.model.content.GlassFinGoodType;
import sa.shpi.advanced.model.content.GlassRawMatType;
import sa.shpi.advanced.model.content.MetalFinGoodType;
import sa.shpi.advanced.model.content.MetalRawMatType;
import sa.shpi.advanced.model.content.PaperFinGoodType;
import sa.shpi.advanced.model.content.PaperRawMatType;
import sa.shpi.advanced.model.content.PlasticFinGoodType;
import sa.shpi.advanced.model.content.PlasticRawMatType;
import sa.shpi.advanced.model.content.RawMatStorageType;
import sa.shpi.advanced.model.content.RawMatType;
import sa.shpi.advanced.model.content.Room;
import sa.shpi.advanced.model.content.RoomType;
import sa.shpi.advanced.model.content.TextileFinGoodType;
import sa.shpi.advanced.model.content.TextileRawMatType;
import sa.shpi.advanced.model.content.UsedFurnishing;
import sa.shpi.advanced.visual.AdvancedMainForm;

/**
 * Form for a room allows a user to add multiple furniture items to a room.
 * Also contains logical steps to validate that the room area does not exceed
 * the structure area, and that if a room uses a preset default, that it does not
 * also use individual furnishing items.
 *
 * @author Kyle
 *
 */
public class RoomDetailForm extends JDialog {
    
    private static final long serialVersionUID = 1L;

    private final JPanel contentPanel = new JPanel();
    private JList furnishingList = new JList();
    private JLabel damageLabel = new JLabel("100%");
    private JSlider damageSlider = new JSlider();
    private JPanel areaPanel = new JPanel();
    private JTextField roomAreaText = new JTextField("1.0");
    private JTextField roomQuantity = new JTextField("1");
    private JPanel quantityPanel = new JPanel();
    private JPanel typePanel = new JPanel();
    private JComboBox roomTypeComboBox = new JComboBox();
    private JPanel furnishingPanel = new JPanel();
    private JPanel damagePanel = new JPanel();
    private JPanel fuelVolumePanel = new JPanel();
    private JTextField fuelVolumeText = new JTextField("1.0");
    private JLabel fuelVolumeLabel = new JLabel("L");
    private JComboBox fuelTypeComboBox = new JComboBox();
    private JComboBox foodFinGoodTypeComboBox = new JComboBox();
    private JComboBox chemFinGoodTypeComboBox = new JComboBox();
    private JComboBox constFinGoodTypeComboBox = new JComboBox();
    private JComboBox paperFinGoodTypeComboBox = new JComboBox();
    private JComboBox metalFinGoodTypeComboBox = new JComboBox();
    private JComboBox textileFinGoodTypeComboBox = new JComboBox();
    private JComboBox plasticFinGoodTypeComboBox = new JComboBox();
    private JComboBox glassFinGoodTypeComboBox = new JComboBox();
    private JPanel finGoodDetailsPanel = new JPanel();
    private JPanel rawMatDetailsPanel = new JPanel();
    private JRadioButton finGoodVolumeRadio = new JRadioButton();
    private JRadioButton finGoodMassRadio = new JRadioButton();
    private JTextField finGoodMatVolume = new JTextField("1.00");
    private JTextField finGoodMatDensity = new JTextField("1.00");
    private JTextField finGoodMatMass = new JTextField("1.00");
    private JRadioButton rawMatVolumeRadio = new JRadioButton();
    private JRadioButton rawMatMassRadio = new JRadioButton();
    private JTextField rawMatVolume = new JTextField("1.00");
    private JTextField rawMatDensity = new JTextField("1.00");
    private JTextField rawMatMass = new JTextField("1.00");
    private JComboBox chemRawMatType = new JComboBox();
    private JComboBox foodRawMatType = new JComboBox();
    private JComboBox paperRawMatType = new JComboBox();
    private JComboBox constRawMatType = new JComboBox();
    private JComboBox textileRawMatType = new JComboBox();
    private JComboBox metalRawMatType = new JComboBox();
    private JComboBox plasticRawMatType = new JComboBox();
    private JComboBox glassRawMatType = new JComboBox();
    private JLabel rawMat = new JLabel(Strings.RAW_MAT_TYPE.toString() + ":");
    private JLabel fuelType = new JLabel(Strings.FUEL_TYPE.toString() + ":");
    private JLabel finGood = new JLabel(Strings.FIN_GOOD_TYPE.toString() + ":");
    private JLabel otherEmisFac = new JLabel(Strings.EMISSIONS_FACTOR.toString() + ":");
    private JTextField otherEmisFacText = new JTextField();
    private JPanel finGoodStoragePanel = new JPanel();
    private JComboBox finGoodStorageType = new JComboBox();
    private JLabel storageTypeLabel = new JLabel(Strings.FIN_STORE_TYPE.toString() + ":");
    private JPanel rawMatStoragePanel = new JPanel();
    private JComboBox rawMatStorageType = new JComboBox();
    private JLabel rawStorageTypeLabel = new JLabel(Strings.RAW_STORE_TYPE.toString() + ":");
    private ImageIcon shpi = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
    private JButton roomTypeHelp = new JButton("?");
    private JButton fuelTypeHelp = new JButton("?");
    private JButton finGoodHelp = new JButton("?");
    private JButton rawMatHelp = new JButton("?");
    private JButton areaHelp = new JButton("?");
    private JButton quantityHelp = new JButton("?");
    private JButton furnishingHelp = new JButton("?");
    private JButton damageHelp = new JButton("?");
    private JButton finGoodStorageHelp =  new JButton("?");
    private JButton rawMatStorageHelp = new JButton("?");
    
    private Room room;
    Industrial ind;
    
    //Validation strings
    String doubleregex = "^[0-9]*[.][0-9]*$";
    String intregex = "^[1-9][0-9]*$";

    private AdvancedMainForm parent;

    /**
     * Create the dialog.
     */
    public RoomDetailForm(AdvancedMainForm parent) {
        super(parent.getFrame());

        room = new Room();
        finGoodVolumeRadio.setSelected(true);
        rawMatVolumeRadio.setSelected(true);
        
        //Initial values
        room.setRoomQuantity(1);
        room.setMatMass(0.00);
        room.setFuelVolume(0.0);
        room.setRawMatMass(0.0);
        room.setOtherEmisFac(0.0);

        setTitle(Strings.ROOM.toString());
        setType(Type.UTILITY);
        setResizable(false);
        setModalityType(ModalityType.APPLICATION_MODAL);
        setDefaultCloseOperation(JDialog.DISPOSE_ON_CLOSE);
        this.parent = parent;

        setBounds(100, 100, 425, 125);
        getContentPane().setLayout(new BorderLayout());
        contentPanel.setBorder(new EmptyBorder(5, 5, 5, 5));
        getContentPane().add(contentPanel, BorderLayout.CENTER);
        GridBagLayout gbl_contentPanel = new GridBagLayout();
        contentPanel.setLayout(gbl_contentPanel);
        contentPanel.setVisible(true);
        
            typePanel.setBorder(new TitledBorder(null,
                    Strings.ROOM_TYPE.toString(), TitledBorder.LEADING,
                    TitledBorder.TOP, null, null));
            GridBagConstraints gbc_panel = new GridBagConstraints();
            gbc_panel.insets = new Insets(0, 0, 5, 0);
            gbc_panel.fill = GridBagConstraints.NONE;
            gbc_panel.gridx = 0;
            gbc_panel.gridy = 0;
            contentPanel.add(typePanel, gbc_panel);
            GridBagLayout gbl_panel = new GridBagLayout();
            typePanel.setLayout(gbl_panel);
            typePanel.setVisible(true);
            
            {
                //Drop down menu for input of room type.
                roomTypeComboBox.addActionListener((ActionEvent e) -> {
                    //Set room type to selection
                    if (roomTypeComboBox.getSelectedItem() == null) {}
                    else room.setRoomType((RoomType) roomTypeComboBox.getSelectedItem());
                    //Initialize appropriate data input fields
                    if (roomTypeComboBox.getSelectedItem() == null) {}
                    else if (room.getRoomType().equals(RoomType.BATHROOM)) {
                        setBounds(100, 100, 425, 570);
                        areaHelp.setVisible(true);
                        areaPanel.setVisible(true);
                        chemFinGoodTypeComboBox.setVisible(false);
                        chemRawMatType.setVisible(false);
                        constFinGoodTypeComboBox.setVisible(false);
                        constRawMatType.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(false);
                        finGoodDetailsPanel.setVisible(false);
                        finGoodHelp.setVisible(false);
                        finGoodStoragePanel.setVisible(false);
                        foodFinGoodTypeComboBox.setVisible(false);
                        foodRawMatType.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(true);
                        glassFinGoodTypeComboBox.setVisible(false);
                        glassRawMatType.setVisible(false);
                        metalFinGoodTypeComboBox.setVisible(false);
                        metalRawMatType.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperFinGoodTypeComboBox.setVisible(false);
                        paperRawMatType.setVisible(false);
                        plasticFinGoodTypeComboBox.setVisible(false);
                        plasticRawMatType.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(false);
                        rawMatDetailsPanel.setVisible(false);
                        rawMatHelp.setVisible(false);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        roomAreaText.setText("2.17");
                        room.setRoomArea(2.17);
                        textileFinGoodTypeComboBox.setVisible(false);
                        textileRawMatType.setVisible(false);
                    } else if (room.getRoomType().equals(RoomType.CONF_ROOM)) {
                        setBounds(100, 100, 425, 570);
                        areaHelp.setVisible(true);
                        areaPanel.setVisible(true);
                        chemFinGoodTypeComboBox.setVisible(false);
                        chemRawMatType.setVisible(false);
                        constFinGoodTypeComboBox.setVisible(false);
                        constRawMatType.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(false);
                        finGoodDetailsPanel.setVisible(false);
                        finGoodHelp.setVisible(false);
                        finGoodStoragePanel.setVisible(false);
                        foodFinGoodTypeComboBox.setVisible(false);
                        foodRawMatType.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(true);
                        glassFinGoodTypeComboBox.setVisible(false);
                        glassRawMatType.setVisible(false);
                        metalFinGoodTypeComboBox.setVisible(false);
                        metalRawMatType.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperFinGoodTypeComboBox.setVisible(false);
                        paperRawMatType.setVisible(false);
                        plasticFinGoodTypeComboBox.setVisible(false);
                        plasticRawMatType.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(false);
                        rawMatDetailsPanel.setVisible(false);
                        rawMatHelp.setVisible(false);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        roomAreaText.setText("15.00");
                        room.setRoomArea(15.00);
                        textileFinGoodTypeComboBox.setVisible(false);
                        textileRawMatType.setVisible(false);
                    } else if (room.getRoomType().equals(RoomType.FUEL_STORE)) {
                        setBounds(100, 100, 425, 380);
                        areaHelp.setVisible(false);
                        areaPanel.setVisible(false);
                        chemFinGoodTypeComboBox.setVisible(false);
                        chemRawMatType.setVisible(false);
                        constFinGoodTypeComboBox.setVisible(false);
                        constRawMatType.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(false);
                        finGoodDetailsPanel.setVisible(false);
                        finGoodHelp.setVisible(false);
                        finGoodStoragePanel.setVisible(false);
                        foodFinGoodTypeComboBox.setVisible(false);
                        foodRawMatType.setVisible(false);
                        fuelType.setVisible(true);
                        fuelTypeComboBox.setVisible(true);
                        fuelTypeHelp.setVisible(true);
                        fuelVolumePanel.setVisible(true);
                        furnishingPanel.setVisible(false);
                        glassFinGoodTypeComboBox.setVisible(false);
                        glassRawMatType.setVisible(false);
                        metalFinGoodTypeComboBox.setVisible(false);
                        metalRawMatType.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperFinGoodTypeComboBox.setVisible(false);
                        paperRawMatType.setVisible(false);
                        plasticFinGoodTypeComboBox.setVisible(false);
                        plasticRawMatType.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(false);
                        rawMatDetailsPanel.setVisible(false);
                        rawMatHelp.setVisible(false);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        room.setRoomArea(0);
                        textileFinGoodTypeComboBox.setVisible(false);
                        textileRawMatType.setVisible(false);
                        fuelTypeComboBox.setSelectedItem(null);
                    } else if (room.getRoomType().equals(RoomType.OFFICE)) {
                        setBounds(100, 100, 425, 570);
                        areaHelp.setVisible(true);
                        areaPanel.setVisible(true);
                        chemFinGoodTypeComboBox.setVisible(false);
                        chemRawMatType.setVisible(false);
                        constFinGoodTypeComboBox.setVisible(false);
                        constRawMatType.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(false);
                        finGoodDetailsPanel.setVisible(false);
                        finGoodHelp.setVisible(false);
                        finGoodStoragePanel.setVisible(false);
                        foodFinGoodTypeComboBox.setVisible(false);
                        foodRawMatType.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(true);
                        glassFinGoodTypeComboBox.setVisible(false);
                        glassRawMatType.setVisible(false);
                        metalFinGoodTypeComboBox.setVisible(false);
                        metalRawMatType.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperFinGoodTypeComboBox.setVisible(false);
                        paperRawMatType.setVisible(false);
                        plasticFinGoodTypeComboBox.setVisible(false);
                        plasticRawMatType.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(false);
                        rawMatDetailsPanel.setVisible(false);
                        rawMatHelp.setVisible(false);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        roomAreaText.setText("8.70");
                        room.setRoomArea(8.70);
                        textileFinGoodTypeComboBox.setVisible(false);
                        textileRawMatType.setVisible(false);
                    } else if (room.getRoomType().equals(RoomType.BREAK_ROOM)) {
                        setBounds(100, 100, 425, 570);
                        areaHelp.setVisible(true);
                        areaPanel.setVisible(true);
                        chemFinGoodTypeComboBox.setVisible(false);
                        chemRawMatType.setVisible(false);
                        constFinGoodTypeComboBox.setVisible(false);
                        constRawMatType.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(false);
                        finGoodDetailsPanel.setVisible(false);
                        finGoodHelp.setVisible(false);
                        finGoodStoragePanel.setVisible(false);
                        foodFinGoodTypeComboBox.setVisible(false);
                        foodRawMatType.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(true);
                        glassFinGoodTypeComboBox.setVisible(false);
                        glassRawMatType.setVisible(false);
                        metalFinGoodTypeComboBox.setVisible(false);
                        metalRawMatType.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperFinGoodTypeComboBox.setVisible(false);
                        paperRawMatType.setVisible(false);
                        plasticFinGoodTypeComboBox.setVisible(false);
                        plasticRawMatType.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(false);
                        rawMatDetailsPanel.setVisible(false);
                        rawMatHelp.setVisible(false);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        roomAreaText.setText("10.00");
                        room.setRoomArea(10.00);
                        textileFinGoodTypeComboBox.setVisible(false);
                        textileRawMatType.setVisible(false);
                    } else if (room.getRoomType().equals(RoomType.FIN_GOOD_STORE)) {
                        setBounds(100, 100, 500, 525);
                        areaHelp.setVisible(false);
                        areaPanel.setVisible(false);
                        chemRawMatType.setVisible(false);
                        constRawMatType.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(true);
                        finGoodDetailsPanel.setVisible(true);
                        finGoodHelp.setVisible(true);
                        finGoodStoragePanel.setVisible(true);
                        foodRawMatType.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(false);
                        glassRawMatType.setVisible(false);
                        metalRawMatType.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperRawMatType.setVisible(false);
                        plasticRawMatType.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(false);
                        rawMatDetailsPanel.setVisible(false);
                        rawMatHelp.setVisible(false);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        room.setRoomArea(0);
                        textileRawMatType.setVisible(false);
                        if (Industrial.getIndustrialType().equals(IndustrialType.FOOD_IND)) {
                            foodFinGoodTypeComboBox.setVisible(true);
                            foodFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.CHEM_IND)) {
                            chemFinGoodTypeComboBox.setVisible(true);
                            chemFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.CONST_IND)) {
                            constFinGoodTypeComboBox.setVisible(true);
                            constFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.PAPER_IND)) {
                            paperFinGoodTypeComboBox.setVisible(true);
                            paperFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.METAL_IND)) {
                            metalFinGoodTypeComboBox.setVisible(true);
                            metalFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.TEXT_IND)) {
                            textileFinGoodTypeComboBox.setVisible(true);
                            textileFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.PLASTIC_IND)) {
                            plasticFinGoodTypeComboBox.setVisible(true);
                            plasticFinGoodTypeComboBox.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.GLASS_IND)) {
                            glassFinGoodTypeComboBox.setVisible(true);
                            glassFinGoodTypeComboBox.setSelectedItem(null);
                        }
                        finGoodStorageType.setSelectedItem(null);
                    } else if (room.getRoomType().equals(RoomType.RAW_MAT_STORAGE)) {
                        setBounds(100, 100, 500, 525);
                        areaHelp.setVisible(false);
                        areaPanel.setVisible(false);
                        chemFinGoodTypeComboBox.setVisible(false);
                        constFinGoodTypeComboBox.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(false);
                        finGoodDetailsPanel.setVisible(false);
                        finGoodHelp.setVisible(false);
                        finGoodStoragePanel.setVisible(false);
                        foodFinGoodTypeComboBox.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(false);
                        glassFinGoodTypeComboBox.setVisible(false);
                        metalFinGoodTypeComboBox.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        paperFinGoodTypeComboBox.setVisible(false);
                        plasticFinGoodTypeComboBox.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(true);
                        rawMatDetailsPanel.setVisible(true);
                        rawMatHelp.setVisible(true);
                        rawMatStoragePanel.setVisible(true);
                        roomTypeHelp.setVisible(true);
                        room.setRoomArea(0);
                        textileFinGoodTypeComboBox.setVisible(false);
                        if (Industrial.getIndustrialType().equals(IndustrialType.CHEM_IND)) {
                            chemRawMatType.setVisible(true);
                            chemRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.PAPER_IND)) {
                            paperRawMatType.setVisible(true);
                            paperRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.CONST_IND)) {
                            constRawMatType.setVisible(true);
                            constRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.TEXT_IND)) {
                            textileRawMatType.setVisible(true);
                            textileRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.METAL_IND)) {
                            metalRawMatType.setVisible(true);
                            metalRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.FOOD_IND)) {
                            foodRawMatType.setVisible(true);
                            foodRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.PLASTIC_IND)) {
                            plasticRawMatType.setVisible(true);
                            plasticRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.GLASS_IND)) {
                            glassRawMatType.setVisible(true);
                            glassRawMatType.setSelectedItem(null);
                        }
                        rawMatStorageType.setSelectedItem(null);
                    } else if (room.getRoomType().equals(RoomType.PROD_FLOOR)){
                        setBounds(100, 100, 500, 675);
                        areaHelp.setVisible(false);
                        areaPanel.setVisible(false);
                        damagePanel.setVisible(true);
                        finGood.setVisible(true);
                        finGoodDetailsPanel.setVisible(true);
                        finGoodHelp.setVisible(true);
                        finGoodStoragePanel.setVisible(false);
                        fuelType.setVisible(false);
                        fuelTypeComboBox.setVisible(false);
                        fuelTypeHelp.setVisible(false);
                        fuelVolumePanel.setVisible(false);
                        furnishingPanel.setVisible(false);
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                        quantityPanel.setVisible(true);
                        rawMat.setVisible(true);
                        rawMatDetailsPanel.setVisible(true);
                        rawMatHelp.setVisible(true);
                        rawMatStoragePanel.setVisible(false);
                        roomTypeHelp.setVisible(true);
                        room.setRoomArea(0);
                        if (Industrial.getIndustrialType().equals(IndustrialType.CHEM_IND)) {
                            chemRawMatType.setVisible(true);
                            chemFinGoodTypeComboBox.setVisible(true);
                            chemFinGoodTypeComboBox.setSelectedItem(null);
                            chemRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.FOOD_IND)) {
                            foodRawMatType.setVisible(true);
                            foodFinGoodTypeComboBox.setVisible(true);
                            foodFinGoodTypeComboBox.setSelectedItem(null);
                            foodRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.METAL_IND)) {
                            metalRawMatType.setVisible(true);
                            metalFinGoodTypeComboBox.setVisible(true);
                            metalFinGoodTypeComboBox.setSelectedItem(null);
                            metalRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.PAPER_IND)) {
                            paperRawMatType.setVisible(true);
                            paperFinGoodTypeComboBox.setVisible(true);
                            paperFinGoodTypeComboBox.setSelectedItem(null);
                            paperRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.TEXT_IND)) {
                            textileRawMatType.setVisible(true);
                            textileFinGoodTypeComboBox.setVisible(true);
                            textileFinGoodTypeComboBox.setSelectedItem(null);
                            textileRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.CONST_IND)) {
                            constRawMatType.setVisible(true);
                            constFinGoodTypeComboBox.setVisible(true);
                            constFinGoodTypeComboBox.setSelectedItem(null);
                            constRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.PLASTIC_IND)) {
                            plasticFinGoodTypeComboBox.setVisible(true);
                            plasticRawMatType.setVisible(true);
                            plasticFinGoodTypeComboBox.setSelectedItem(null);
                            plasticRawMatType.setSelectedItem(null);
                        } else if (Industrial.getIndustrialType().equals(IndustrialType.GLASS_IND)) {
                            glassFinGoodTypeComboBox.setVisible(true);
                            glassRawMatType.setVisible(true);
                            glassFinGoodTypeComboBox.setSelectedItem(null);
                            glassRawMatType.setSelectedItem(null);
                        }
                    }
                });
                roomTypeComboBox.setModel(new DefaultComboBoxModel(RoomType
                        .values()));
                roomTypeComboBox.setSelectedItem(null);
                GridBagConstraints gbc_roomTypeComboBox = new GridBagConstraints();
                gbc_roomTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_roomTypeComboBox.gridwidth = 2;
                gbc_roomTypeComboBox.gridx = 0;
                gbc_roomTypeComboBox.gridy = 0;
                typePanel.add(roomTypeComboBox, gbc_roomTypeComboBox);
            }
            {
                //Help dialog for room type.
                roomTypeHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Añadir un área de la industria.",
                            Strings.ROOM_TYPE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_roomTypeHelp = new GridBagConstraints();
                gbc_roomTypeHelp.anchor = GridBagConstraints.CENTER;
                gbc_roomTypeHelp.gridx = 2;
                gbc_roomTypeHelp.gridy = 0;
                typePanel.add(roomTypeHelp, gbc_roomTypeHelp);
            }
            {
                //Drop down menu for fuel type.
                fuelTypeComboBox.addActionListener((ActionEvent e) -> {
                    room.setFuelType((FuelType) fuelTypeComboBox.getSelectedItem());
                });
                fuelTypeComboBox.setModel(new DefaultComboBoxModel(FuelType.values()));
                GridBagConstraints gbc_fuelType = new GridBagConstraints();
                gbc_fuelType.anchor = GridBagConstraints.CENTER;
                gbc_fuelType.fill = GridBagConstraints.HORIZONTAL;
                gbc_fuelType.gridx = 1;
                gbc_fuelType.gridy = 1;
                typePanel.add(fuelTypeComboBox, gbc_fuelType);
                fuelTypeComboBox.setVisible(false);
            }
            {
                //Help dialog for fuel type.
                fuelTypeHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Selección del combustible quemado para fabricación del producto.",
                            Strings.FUEL_TYPE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_fuelTypeHelp = new GridBagConstraints();
                gbc_fuelTypeHelp.anchor = GridBagConstraints.CENTER;
                gbc_fuelTypeHelp.gridx = 2;
                gbc_fuelTypeHelp.gridy = 1;
                typePanel.add(fuelTypeHelp, gbc_fuelTypeHelp);
                fuelTypeHelp.setVisible(false);
            }
            {
                GridBagConstraints gbc_fuelType = new GridBagConstraints();
                gbc_fuelType.anchor = GridBagConstraints.CENTER;
                gbc_fuelType.gridy = 1;
                gbc_fuelType.gridx = 0;
                typePanel.add(fuelType, gbc_fuelType);
                fuelType.setVisible(false);
            }
            {
                GridBagConstraints gbc_finGood = new GridBagConstraints();
                gbc_finGood.anchor = GridBagConstraints.CENTER;
                gbc_finGood.gridy = 1;
                gbc_finGood.gridx = 0;
                typePanel.add(finGood, gbc_finGood);
                finGood.setVisible(false);
            }
            /**
             * The following are drop down menus for the finished good types
             * contained in the industrial building.
             */
            {
                foodFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (foodFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.ALCOHOL)) {
                        room.setFinGoodType(FinGoodType.ALCOHOL);
                        finGoodMatDensity.setText("1191.67");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.CANNED)) {
                        room.setFinGoodType(FinGoodType.CANNED);
                        finGoodMatDensity.setText("1000.00");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.DAIRY)) {
                        room.setFinGoodType(FinGoodType.DAIRY);
                        finGoodMatDensity.setText("947.526");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.GRAIN)) {
                        room.setFinGoodType(FinGoodType.GRAIN);
                        finGoodMatDensity.setText("436.985");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.MEAT)) {
                        room.setFinGoodType(FinGoodType.MEAT);
                        finGoodMatDensity.setText("786.672");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.PRODUCE)) {
                        room.setFinGoodType(FinGoodType.PRODUCE);
                        finGoodMatDensity.setText("713");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (foodFinGoodTypeComboBox.getSelectedItem().equals(FoodFinGoodType.FOOD)) {
                        room.setFinGoodType(FinGoodType.FOOD);
                        finGoodMatDensity.setText("845.9755");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                foodFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(FoodFinGoodType.values()));
                GridBagConstraints gbc_foodFinGoodTypeComboBox = new GridBagConstraints();
                gbc_foodFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_foodFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_foodFinGoodTypeComboBox.gridx = 1;
                gbc_foodFinGoodTypeComboBox.gridy = 1;
                typePanel.add(foodFinGoodTypeComboBox, gbc_foodFinGoodTypeComboBox);
                foodFinGoodTypeComboBox.setVisible(false);
            }
            {
                chemFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (chemFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.CHEM)) {
                        room.setFinGoodType(FinGoodType.CHEM);
                        finGoodMatDensity.setText("1084.3333");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.POOL_CHEM)) {
                        room.setFinGoodType(FinGoodType.POOL_CHEM);
                        finGoodMatDensity.setText("920");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.PAINT)) {
                        room.setFinGoodType(FinGoodType.PAINT);
                        finGoodMatDensity.setText("1198");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.ANTIFREEZE)) {
                        room.setFinGoodType(FinGoodType.ANTIFREEZE);
                        finGoodMatDensity.setText("1113");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.RODENTICIDE)) {
                        room.setFinGoodType(FinGoodType.RODENTICIDE);
                        finGoodMatDensity.setText("1390");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.AP_CLEANER)) {
                        room.setFinGoodType(FinGoodType.AP_CLEANER);
                        finGoodMatDensity.setText("1000");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (chemFinGoodTypeComboBox.getSelectedItem().equals(ChemFinGoodType.LAUNDRY)) {
                        room.setFinGoodType(FinGoodType.LAUNDRY);
                        finGoodMatDensity.setText("885");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                chemFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(ChemFinGoodType.values()));
                GridBagConstraints gbc_chemFinGoodTypeComboBox = new GridBagConstraints();
                gbc_chemFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_chemFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_chemFinGoodTypeComboBox.gridx = 1;
                gbc_chemFinGoodTypeComboBox.gridy = 1;
                typePanel.add(chemFinGoodTypeComboBox, gbc_chemFinGoodTypeComboBox);
                chemFinGoodTypeComboBox.setVisible(false);
            }
            {
                plasticFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (plasticFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.PLASTIC)) {
                        room.setFinGoodType(FinGoodType.PLASTIC);
                        finGoodMatDensity.setText("1091");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.PVC)) {
                        room.setFinGoodType(FinGoodType.PVC);
                        finGoodMatDensity.setText("1375");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.PET)) {
                        room.setFinGoodType(FinGoodType.PET);
                        finGoodMatDensity.setText("1300");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.PS)) {
                        room.setFinGoodType(FinGoodType.PS);
                        finGoodMatDensity.setText("1050");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.HDPE)) {
                        room.setFinGoodType(FinGoodType.HDPE);
                        finGoodMatDensity.setText("950");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.LDPE)) {
                        room.setFinGoodType(FinGoodType.LDPE);
                        finGoodMatDensity.setText("925");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (plasticFinGoodTypeComboBox.getSelectedItem().equals(PlasticFinGoodType.PP)) {
                        room.setFinGoodType(FinGoodType.PP);
                        finGoodMatDensity.setText("946");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                plasticFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(PlasticFinGoodType.values()));
                GridBagConstraints gbc_plasticFinGoodTypeComboBox = new GridBagConstraints();
                gbc_plasticFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_plasticFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_plasticFinGoodTypeComboBox.gridx = 1;
                gbc_plasticFinGoodTypeComboBox.gridy = 1;
                typePanel.add(plasticFinGoodTypeComboBox, gbc_plasticFinGoodTypeComboBox);
                plasticFinGoodTypeComboBox.setVisible(false);
            }
            {
                glassFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (glassFinGoodTypeComboBox.getSelectedItem() == null) {} 
                    else if (glassFinGoodTypeComboBox.getSelectedItem().equals(GlassFinGoodType.GLASS)) {
                        room.setFinGoodType(FinGoodType.GLASS);
                        finGoodMatDensity.setText("2600");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                glassFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(GlassFinGoodType.values()));
                GridBagConstraints gbc_glassFinGoodTypeComboBox = new GridBagConstraints();
                gbc_glassFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_glassFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_glassFinGoodTypeComboBox.gridx = 1;
                gbc_glassFinGoodTypeComboBox.gridy = 1;
                typePanel.add(glassFinGoodTypeComboBox, gbc_glassFinGoodTypeComboBox);
                glassFinGoodTypeComboBox.setVisible(false);
            }
            {
                constFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (constFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (constFinGoodTypeComboBox.getSelectedItem().equals(ConstFinGoodType.CONST)) {
                        room.setFinGoodType(FinGoodType.CONST);
                        finGoodMatDensity.setText("1074.375");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (constFinGoodTypeComboBox.getSelectedItem().equals(ConstFinGoodType.CONCRETE)) {
                        room.setFinGoodType(FinGoodType.CONCRETE);
                        finGoodMatDensity.setText("1500");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (constFinGoodTypeComboBox.getSelectedItem().equals(ConstFinGoodType.WOOD)) {
                        room.setFinGoodType(FinGoodType.WOOD);
                        finGoodMatDensity.setText("648.75");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                constFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(ConstFinGoodType.values()));
                GridBagConstraints gbc_constFinGoodTypeComboBox = new GridBagConstraints();
                gbc_constFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_constFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_constFinGoodTypeComboBox.gridx = 1;
                gbc_constFinGoodTypeComboBox.gridy = 1;
                typePanel.add(constFinGoodTypeComboBox, gbc_constFinGoodTypeComboBox);
                constFinGoodTypeComboBox.setVisible(false);
            }
            {
                paperFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (paperFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (paperFinGoodTypeComboBox.getSelectedItem().equals(PaperFinGoodType.PAPER)) {
                        room.setFinGoodType(FinGoodType.PAPER);
                        finGoodMatDensity.setText("616.25");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (paperFinGoodTypeComboBox.getSelectedItem().equals(PaperFinGoodType.BATH_TISSUE)) {
                        room.setFinGoodType(FinGoodType.BATH_TISSUE);
                        finGoodMatDensity.setText("375");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (paperFinGoodTypeComboBox.getSelectedItem().equals(PaperFinGoodType.CARDBOARD)) {
                        room.setFinGoodType(FinGoodType.CARDBOARD);
                        finGoodMatDensity.setText("700");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (paperFinGoodTypeComboBox.getSelectedItem().equals(PaperFinGoodType.COMP_PAPER)) {
                        room.setFinGoodType(FinGoodType.COMP_PAPER);
                        finGoodMatDensity.setText("740");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (paperFinGoodTypeComboBox.getSelectedItem().equals(PaperFinGoodType.NEWSPAPER)) {
                        room.setFinGoodType(FinGoodType.NEWSPAPER);
                        finGoodMatDensity.setText("650");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                paperFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(PaperFinGoodType.values()));
                GridBagConstraints gbc_paperFinGoodTypeComboBox = new GridBagConstraints();
                gbc_paperFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_paperFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_paperFinGoodTypeComboBox.gridx = 1;
                gbc_paperFinGoodTypeComboBox.gridy = 1;
                typePanel.add(paperFinGoodTypeComboBox, gbc_paperFinGoodTypeComboBox);
                paperFinGoodTypeComboBox.setVisible(false);
            }
            {
                metalFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (metalFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (metalFinGoodTypeComboBox.getSelectedItem().equals(MetalFinGoodType.METAL)) {
                        room.setFinGoodType(FinGoodType.METAL);
                        finGoodMatDensity.setText("6028.8");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (metalFinGoodTypeComboBox.getSelectedItem().equals(MetalFinGoodType.ALUMINUM)) {
                        room.setFinGoodType(FinGoodType.ALUMINUM);
                        finGoodMatDensity.setText("2712");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (metalFinGoodTypeComboBox.getSelectedItem().equals(MetalFinGoodType.COPPER)) {
                        room.setFinGoodType(FinGoodType.COPPER);
                        finGoodMatDensity.setText("8940");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (metalFinGoodTypeComboBox.getSelectedItem().equals(MetalFinGoodType.IRON)) {
                        room.setFinGoodType(FinGoodType.IRON);
                        finGoodMatDensity.setText("7874");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (metalFinGoodTypeComboBox.getSelectedItem().equals(MetalFinGoodType.STEEL)) {
                        room.setFinGoodType(FinGoodType.STEEL);
                        finGoodMatDensity.setText("7850");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (metalFinGoodTypeComboBox.getSelectedItem().equals(MetalFinGoodType.ALLOY)) {
                        room.setFinGoodType(FinGoodType.ALLOY);
                        finGoodMatDensity.setText("2768");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                metalFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(MetalFinGoodType.values()));
                GridBagConstraints gbc_metalFinGoodTypeComboBox = new GridBagConstraints();
                gbc_metalFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_metalFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_metalFinGoodTypeComboBox.gridx = 1;
                gbc_metalFinGoodTypeComboBox.gridy = 1;
                typePanel.add(metalFinGoodTypeComboBox, gbc_metalFinGoodTypeComboBox);
                metalFinGoodTypeComboBox.setVisible(false);
            }
            {
                textileFinGoodTypeComboBox.addActionListener((ActionEvent e) -> {
                    if (textileFinGoodTypeComboBox.getSelectedItem() == null) {}
                    else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.TEXTILE)) {
                        room.setFinGoodType(FinGoodType.TEXTILE);
                        finGoodMatDensity.setText("1067");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.COTTON)) {
                        room.setFinGoodType(FinGoodType.COTTON);
                        finGoodMatDensity.setText("1480");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.CARPET)) {
                        room.setFinGoodType(FinGoodType.CARPET);
                        finGoodMatDensity.setText("226");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.LEATHER)) {
                        room.setFinGoodType(FinGoodType.LEATHER);
                        finGoodMatDensity.setText("860");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.POLYESTER)) {
                        room.setFinGoodType(FinGoodType.POLYESTER);
                        finGoodMatDensity.setText("1300");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.VINYL)) {
                        room.setFinGoodType(FinGoodType.VINYL);
                        finGoodMatDensity.setText("1225");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    } else if (textileFinGoodTypeComboBox.getSelectedItem().equals(TextileFinGoodType.WOOL)) {
                        room.setFinGoodType(FinGoodType.WOOL);
                        finGoodMatDensity.setText("1314");
                        finGoodMatMass.setText(String.format("%.4f", Double.parseDouble(finGoodMatDensity.getText())
                                * Double.parseDouble(finGoodMatVolume.getText())));
                    }
                });
                textileFinGoodTypeComboBox.setModel(new DefaultComboBoxModel(TextileFinGoodType.values()));
                GridBagConstraints gbc_textileFinGoodTypeComboBox = new GridBagConstraints();
                gbc_textileFinGoodTypeComboBox.anchor = GridBagConstraints.CENTER;
                gbc_textileFinGoodTypeComboBox.fill = GridBagConstraints.HORIZONTAL;
                gbc_textileFinGoodTypeComboBox.gridx = 1;
                gbc_textileFinGoodTypeComboBox.gridy = 1;
                typePanel.add(textileFinGoodTypeComboBox, gbc_textileFinGoodTypeComboBox);
                textileFinGoodTypeComboBox.setVisible(false);
            }
            {
                //Help dialog for finished goods type.
                finGoodHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Selección de la categoría del producto fabricado en la industria.",
                            Strings.FIN_GOOD_TYPE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_finGoodHelp = new GridBagConstraints();
                gbc_finGoodHelp.anchor = GridBagConstraints.CENTER;
                gbc_finGoodHelp.gridx = 2;
                gbc_finGoodHelp.gridy = 1;
                typePanel.add(finGoodHelp, gbc_finGoodHelp);
                finGoodHelp.setVisible(false);
            }
            {
                GridBagConstraints gbc_rawMat = new GridBagConstraints();
                gbc_rawMat.anchor = GridBagConstraints.CENTER;
                gbc_rawMat.gridy = 2;
                gbc_rawMat.gridx = 0;
                typePanel.add(rawMat, gbc_rawMat);
                rawMat.setVisible(false);
            }
            /**
             * The following are drop down menus for raw material types.
             */
            {
                textileRawMatType.addActionListener((ActionEvent e) -> {
                    if (textileRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (textileRawMatType.getSelectedItem().equals(TextileRawMatType.TEXTILE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.TEXTILE);
                        rawMatDensity.setText("1313.3333");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (textileRawMatType.getSelectedItem().equals(TextileRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (textileRawMatType.getSelectedItem().equals(TextileRawMatType.COTTON)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.COTTON);
                        rawMatDensity.setText("1480");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (textileRawMatType.getSelectedItem().equals(TextileRawMatType.LEATHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.LEATHER);
                        rawMatDensity.setText("860");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (textileRawMatType.getSelectedItem().equals(TextileRawMatType.POLYESTER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.POLYESTER);
                        rawMatDensity.setText("1300");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                textileRawMatType.setModel(new DefaultComboBoxModel(TextileRawMatType.values()));
                GridBagConstraints gbc_textileRawMatType = new GridBagConstraints();
                gbc_textileRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_textileRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_textileRawMatType.gridx = 1;
                gbc_textileRawMatType.gridy = 2;
                typePanel.add(textileRawMatType, gbc_textileRawMatType);
                textileRawMatType.setVisible(false);
            }
            {
                foodRawMatType.addActionListener((ActionEvent e) -> {
                    if (foodRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.FOOD)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.FOOD);
                        rawMatDensity.setText("");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.BEANS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.BEANS);
                        rawMatDensity.setText("819.99");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.BEEF)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.BEEF);
                        rawMatDensity.setText("881");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.BUTTER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.BUTTER);
                        rawMatDensity.setText("959.47");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.CHICKEN)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CHICKEN);
                        rawMatDensity.setText("1121");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.CORN)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CORN);
                        rawMatDensity.setText("593");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.FISH)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.FISH);
                        rawMatDensity.setText("881");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.LAMB)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.LAMB);
                        rawMatDensity.setText("1487.82");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.OATS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.OATS);
                        rawMatDensity.setText("417");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.PORK)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PORK);
                        rawMatDensity.setText("591.75");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.POTATOES)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.POTATOES);
                        rawMatDensity.setText("641");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.RICE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.RICE);
                        rawMatDensity.setText("833");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.SOY)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SOY);
                        rawMatDensity.setText("721");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.SUGARCANE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SUGARCANE);
                        rawMatDensity.setText("320.4");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.TURKEY)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.TURKEY);
                        rawMatDensity.setText("570.61");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (foodRawMatType.getSelectedItem().equals(FoodRawMatType.WHEAT)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.WHEAT);
                        rawMatDensity.setText("769");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                foodRawMatType.setModel(new DefaultComboBoxModel(FoodRawMatType.values()));
                GridBagConstraints gbc_foodRawMatType = new GridBagConstraints();
                gbc_foodRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_foodRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_foodRawMatType.gridx = 1;
                gbc_foodRawMatType.gridy = 2;
                typePanel.add(foodRawMatType, gbc_foodRawMatType);
                foodRawMatType.setVisible(false);
            }
            {
                metalRawMatType.addActionListener((ActionEvent e) -> {
                    if (metalRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (metalRawMatType.getSelectedItem().equals(MetalRawMatType.METAL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.METAL);
                        rawMatDensity.setText("6145.3333");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (metalRawMatType.getSelectedItem().equals(MetalRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (metalRawMatType.getSelectedItem().equals(MetalRawMatType.STEEL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.STEEL);
                        rawMatDensity.setText("7850");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (metalRawMatType.getSelectedItem().equals(MetalRawMatType.IRON)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.IRON);
                        rawMatDensity.setText("7874");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (metalRawMatType.getSelectedItem().equals(MetalRawMatType.ALUMINUM)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ALUMINUM);
                        rawMatDensity.setText("2712");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                metalRawMatType.setModel(new DefaultComboBoxModel(MetalRawMatType.values()));
                GridBagConstraints gbc_metalRawMatType = new GridBagConstraints();
                gbc_metalRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_metalRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_metalRawMatType.gridx = 1;
                gbc_metalRawMatType.gridy = 2;
                typePanel.add(metalRawMatType, gbc_metalRawMatType);
                metalRawMatType.setVisible(false);
            }
            {
                constRawMatType.addActionListener((ActionEvent e) -> {
                    if (constRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (constRawMatType.getSelectedItem().equals(ConstRawMatType.CONST)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CONST);
                        rawMatDensity.setText("1073.5833");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (constRawMatType.getSelectedItem().equals(ConstRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (constRawMatType.getSelectedItem().equals(ConstRawMatType.CINDER_BLOCK)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CINDER_BLOCK);
                        rawMatDensity.setText("650");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (constRawMatType.getSelectedItem().equals(ConstRawMatType.CLAY_BRICK)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CLAY_BRICK);
                        rawMatDensity.setText("1922");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (constRawMatType.getSelectedItem().equals(ConstRawMatType.WOOD)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.WOOD);
                        rawMatDensity.setText("648.75");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                constRawMatType.setModel(new DefaultComboBoxModel(ConstRawMatType.values()));
                GridBagConstraints gbc_constRawMatType = new GridBagConstraints();
                gbc_constRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_constRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_constRawMatType.gridx = 1;
                gbc_constRawMatType.gridy = 2;
                typePanel.add(constRawMatType, gbc_constRawMatType);
                constRawMatType.setVisible(false);
            }
            {
                paperRawMatType.addActionListener((ActionEvent e) -> {
                    if (paperRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.PAPER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PAPER);
                        rawMatDensity.setText("1687.3409");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.BLEACH)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.BLEACH);
                        rawMatDensity.setText("1110");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.CHALK)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CHALK);
                        rawMatDensity.setText("2499");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.CLAY)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CLAY);
                        rawMatDensity.setText("1330");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.COTTON)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.COTTON);
                        rawMatDensity.setText("1480");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.GUAR_GUM)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.GUAR_GUM);
                        rawMatDensity.setText("700");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.ROSIN)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ROSIN);
                        rawMatDensity.setText("1073");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.SOD_HYDRO)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SOD_HYDRO);
                        rawMatDensity.setText("2130");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.SOD_SULF)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SOD_SULF);
                        rawMatDensity.setText("1860");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.STARCH)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.STARCH);
                        rawMatDensity.setText("1500");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.TITANIUM_DIOX)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.TITANIUM_DIOX);
                        rawMatDensity.setText("4230");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (paperRawMatType.getSelectedItem().equals(PaperRawMatType.WOOD_CHIPS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.WOOD_CHIPS);
                        rawMatDensity.setText("648.75");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                paperRawMatType.setModel(new DefaultComboBoxModel(PaperRawMatType.values()));
                GridBagConstraints gbc_paperRawMatType = new GridBagConstraints();
                gbc_paperRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_paperRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_paperRawMatType.gridx = 1;
                gbc_paperRawMatType.gridy = 2;
                typePanel.add(paperRawMatType, gbc_paperRawMatType);
                paperRawMatType.setVisible(false);
            }
            {
                chemRawMatType.addActionListener((ActionEvent e) -> {
                    if (chemRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.CHEM)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CHEM);
                        rawMatDensity.setText("1264.6244");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ACETIC_ACID)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ACETIC_ACID);
                        rawMatDensity.setText("1050");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ACETONE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ACETONE);
                        rawMatDensity.setText("791");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.AMMONIA)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.AMMONIA);
                        rawMatDensity.setText("681.9");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.AMM_NITRATE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.AMM_NITRATE);
                        rawMatDensity.setText("1730");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.BENZENE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.BENZENE);
                        rawMatDensity.setText("876.50");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.BISPHENOL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.BISPHENOL);
                        rawMatDensity.setText("1200");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.CARBON_BLACK)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CARBON_BLACK);
                        rawMatDensity.setText("1950");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.CHLORINE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CHLORINE);
                        rawMatDensity.setText("1422");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.CYCLOHEXANE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.CYCLOHEXANE);
                        rawMatDensity.setText("779.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ETHYLENE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ETHYLENE);
                        rawMatDensity.setText("1.18");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ETHYLENE_DI)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ETHYLENE_DI);
                        rawMatDensity.setText("1250");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ETHYLENE_GLYCOL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ETHYLENE_GLYCOL);
                        rawMatDensity.setText("1110");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ETHYL_OX)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ETHYL_OX);
                        rawMatDensity.setText("882.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.FORMALDEHYDE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.FORMALDEHYDE);
                        rawMatDensity.setText("815.30");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.HYDROCHLORIC)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.HYDROCHLORIC);
                        rawMatDensity.setText("1048");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.ISOBUTYLENE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.ISOBUTYLENE);
                        rawMatDensity.setText("587.90");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.METHANOL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.METHANOL);
                        rawMatDensity.setText("791.80");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.NITRIC_ACID)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.NITRIC_ACID);
                        rawMatDensity.setText("1510.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.NITROGEN)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.NITROGEN);
                        rawMatDensity.setText("807");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.OXYGEN)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.OXYGEN);
                        rawMatDensity.setText("1141");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.PHENOL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PHENOL);
                        rawMatDensity.setText("1070");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.PHOS_ACID)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PHOS_ACID);
                        rawMatDensity.setText("1890");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.POTASH)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.POTASH);
                        rawMatDensity.setText("1100");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.PROPYLENE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PROPYLENE);
                        rawMatDensity.setText("613.9");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.PROP_OX)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PROP_OX);
                        rawMatDensity.setText("830.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.SOD_CARB)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SOD_CARB);
                        rawMatDensity.setText("2540");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.SOD_HYDRO)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SOD_HYDRO);
                        rawMatDensity.setText("2130");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.SOD_SILI)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SOD_SILI);
                        rawMatDensity.setText("2400");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.STYRENE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.STYRENE);
                        rawMatDensity.setText("909.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.SULF_ACID)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SULF_ACID);
                        rawMatDensity.setText("1840");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.TEREPHTALIC_ACID)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.TEREPHTALIC_ACID);
                        rawMatDensity.setText("1520");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.TITANIUM_DIOX)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.TITANIUM_DIOX);
                        rawMatDensity.setText("4230");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.UREA)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.UREA);
                        rawMatDensity.setText("1320");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.VC)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.VC);
                        rawMatDensity.setText("911.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.VINYL_ACE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.VINYL_ACE);
                        rawMatDensity.setText("934.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (chemRawMatType.getSelectedItem().equals(ChemRawMatType.XYLENE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.XYLENE);
                        rawMatDensity.setText("864.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                chemRawMatType.setModel(new DefaultComboBoxModel(ChemRawMatType.values()));
                GridBagConstraints gbc_chemRawMatType = new GridBagConstraints();
                gbc_chemRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_chemRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_chemRawMatType.gridx = 1;
                gbc_chemRawMatType.gridy = 2;
                typePanel.add(chemRawMatType, gbc_chemRawMatType);
                chemRawMatType.setVisible(false);
            }
            {
                plasticRawMatType.addActionListener((ActionEvent e) -> {
                    if (plasticRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.PLASTIC)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PLASTIC);
                        rawMatDensity.setText("1009.2800");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.COAL)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.COAL);
                        rawMatDensity.setText("1346");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.NAT_GAS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.NAT_GAS);
                        rawMatDensity.setText("0.80");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.PETROLEUM)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PETROLEUM);
                        rawMatDensity.setText("820");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.POLYESTER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.POLYESTER);
                        rawMatDensity.setText("1300");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.PP)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PP);
                        rawMatDensity.setText("946.00");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.PS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PS);
                        rawMatDensity.setText("1050");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.PVC)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PVC);
                        rawMatDensity.setText("1375");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.PET)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.PET);
                        rawMatDensity.setText("1380");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.LDPE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.LDPE);
                        rawMatDensity.setText("925");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (plasticRawMatType.getSelectedItem().equals(PlasticRawMatType.HDPE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.HDPE);
                        rawMatDensity.setText("950");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                plasticRawMatType.setModel(new DefaultComboBoxModel(PlasticRawMatType.values()));
                GridBagConstraints gbc_plasticRawMatType = new GridBagConstraints();
                gbc_plasticRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_plasticRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_plasticRawMatType.gridx = 1;
                gbc_plasticRawMatType.gridy = 2;
                typePanel.add(plasticRawMatType, gbc_plasticRawMatType);
                plasticRawMatType.setVisible(false);
            }
            {
                glassRawMatType.addActionListener((ActionEvent e) -> {
                    if (glassRawMatType.getSelectedItem() == null) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.GLASS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.GLASS);
                        rawMatDensity.setText("2627.60");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.OTHER)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 550);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 750);
                        }
                        room.setRawMatType(RawMatType.OTHER);
                        otherEmisFac.setVisible(true);
                        otherEmisFacText.setVisible(true);
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.DOLOMITE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.DOLOMITE);
                        rawMatDensity.setText("2850");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.LIMESTONE)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.LIMESTONE);
                        rawMatDensity.setText("2500");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.SILICA)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SILICA);
                        rawMatDensity.setText("2648");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.SODA_ASH)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.SODA_ASH);
                        rawMatDensity.setText("2540");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    } else if (glassRawMatType.getSelectedItem().equals(GlassRawMatType.REC_GLASS)) {
                        if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                            setBounds(100, 100, 475, 525);
                        } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                            setBounds(100, 100, 500, 675);
                        }
                        room.setRawMatType(RawMatType.REC_GLASS);
                        rawMatDensity.setText("2600");
                        rawMatMass.setText(String.format("%.4f", Double.parseDouble(rawMatDensity.getText()) * 
                                Double.parseDouble(rawMatVolume.getText())));
                        otherEmisFac.setVisible(false);
                        otherEmisFacText.setVisible(false);
                    }
                });
                glassRawMatType.setModel(new DefaultComboBoxModel(GlassRawMatType.values()));
                GridBagConstraints gbc_glassRawMatType = new GridBagConstraints();
                gbc_glassRawMatType.anchor = GridBagConstraints.CENTER;
                gbc_glassRawMatType.fill = GridBagConstraints.HORIZONTAL;
                gbc_glassRawMatType.gridx = 1;
                gbc_glassRawMatType.gridy = 2;
                typePanel.add(glassRawMatType, gbc_glassRawMatType);
                glassRawMatType.setVisible(false);
            }
            {
                GridBagConstraints gbc_otherEmisFac = new GridBagConstraints();
                gbc_otherEmisFac.anchor = GridBagConstraints.LINE_START;
                gbc_otherEmisFac.gridx = 0;
                gbc_otherEmisFac.gridy = 3;
                typePanel.add(otherEmisFac, gbc_otherEmisFac);
                otherEmisFac.setVisible(false);
            }
            {
                otherEmisFacText.setText("0.00");
                otherEmisFacText.addFocusListener(new FocusListener() {

                    @Override
                    public void focusGained(FocusEvent e) {
                        otherEmisFacText.selectAll();
                    }

                    @Override
                    public void focusLost(FocusEvent e) {
                        if (otherEmisFacText.getText().matches(doubleregex)) {
                            String value = String.format("%.2f", Double.parseDouble(otherEmisFacText.getText()));
                            otherEmisFacText.setText(value);
                            room.setOtherEmisFac(Double.parseDouble(value));
                        } else if (otherEmisFacText.getText().matches(intregex)) {
                            String value = otherEmisFacText.getText() + ".00";
                            otherEmisFacText.setText(value);
                            room.setOtherEmisFac(Double.parseDouble(value));
                        } else {
                            ImageIcon shpi = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                            otherEmisFacText.setText("0.00");
                            room.setOtherEmisFac(0.00);
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        }
                    }
                    
                });
                GridBagConstraints gbc_otherEmisFacText = new GridBagConstraints();
                gbc_otherEmisFacText.anchor = GridBagConstraints.CENTER;
                gbc_otherEmisFacText.fill = GridBagConstraints.HORIZONTAL;
                gbc_otherEmisFacText.gridy = 3;
                gbc_otherEmisFacText.gridx = 1;
                gbc_otherEmisFacText.gridwidth = 2;
                typePanel.add(otherEmisFacText, gbc_otherEmisFacText);
                otherEmisFacText.setVisible(false);
                otherEmisFacText.setColumns(10);
                otherEmisFacText.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                //Help dialog for raw material type.
                rawMatHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Selección de la materiale usado para fabricaccion para fabricación del producto.",
                            Strings.RAW_MAT_TYPE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_rawMatHelp = new GridBagConstraints();
                gbc_rawMatHelp.anchor = GridBagConstraints.CENTER;
                gbc_rawMatHelp.gridx = 2;
                gbc_rawMatHelp.gridy = 2;
                typePanel.add(rawMatHelp, gbc_rawMatHelp);
                rawMatHelp.setVisible(false);
            }

            areaPanel.setBorder(new TitledBorder(Strings.ROOM_AREA.toString()));
            GridBagConstraints gbc_panel1 = new GridBagConstraints();
            gbc_panel1.fill = GridBagConstraints.HORIZONTAL;
            gbc_panel1.insets = new Insets(0, 0, 5, 0);
            gbc_panel1.gridx = 0;
            gbc_panel1.gridy = 2;
            contentPanel.add(areaPanel, gbc_panel1);
            GridBagLayout gbl_panel1 = new GridBagLayout();
            areaPanel.setLayout(gbl_panel1);
            areaPanel.setVisible(false);
            {
                Component verticalStrut = Box.createVerticalStrut(10);
                GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                gbc_verticalStrut.gridy = 0;
                areaPanel.add(verticalStrut, gbc_verticalStrut);
            }
            {
                //Text box for inupt of room area.
                roomAreaText.setHorizontalAlignment(SwingConstants.RIGHT);
                roomAreaText.addFocusListener(new FocusListener() {
                    /*
                     * The FocusListener assigns a value to roomarea when the user
                     * exits the text entry field.
                     */
                    @Override
                    public void focusGained(FocusEvent e) {
                        roomAreaText.selectAll();
                    }

                    @Override
                    public void focusLost(FocusEvent e) {
                        //Validate all inputs.  
                        String roomArea = roomAreaText.getText();
                        if (roomArea.matches(doubleregex)) {
                            //Set roomarea to the number entered in the field.
                            room.setRoomArea(Double.parseDouble(roomArea));
                        } else if (roomArea.matches(intregex)) {
                            String intvalue = roomArea + ".0";
                            room.setRoomArea(Double.parseDouble(intvalue));
                            roomAreaText.setText(intvalue);
                        } else {
                            roomAreaText.setText("0.00");
                            room.setRoomArea(0.00);
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                        }
                    }
                });

                GridBagConstraints gbc_roomAreaText = new GridBagConstraints();
                gbc_roomAreaText.anchor = GridBagConstraints.CENTER;
                gbc_roomAreaText.fill = GridBagConstraints.HORIZONTAL;
                gbc_roomAreaText.gridy = 1;
                gbc_roomAreaText.gridx = 0;
                areaPanel.add(roomAreaText, gbc_roomAreaText);
                roomAreaText.setColumns(10);
                roomAreaText.setHorizontalAlignment(SwingConstants.CENTER);

            }
            {
                Component horizontalStrut = Box.createHorizontalStrut(295);
                GridBagConstraints gbc_horizontalStrut = new GridBagConstraints();
                gbc_horizontalStrut.gridy = 1;
                gbc_horizontalStrut.gridx = 0;
                areaPanel.add(horizontalStrut, gbc_horizontalStrut);
            }
            {
                JLabel roomAreaLabel = new JLabel("m^2");
                GridBagConstraints gbc_roomAreaLabel = new GridBagConstraints();
                gbc_roomAreaLabel.anchor = GridBagConstraints.CENTER;
                gbc_roomAreaLabel.gridy = 1;
                gbc_roomAreaLabel.gridx = 1;
                areaPanel.add(roomAreaLabel, gbc_roomAreaLabel);
            }
            {
                Component verticalStrut = Box.createVerticalStrut(10);
                GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                gbc_verticalStrut.gridy = 2;
                areaPanel.add(verticalStrut, gbc_verticalStrut);
            }
            {
                //Help dialog for area input
                areaHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "El área, en metros cuadrados (m^2).\nLa área es establece en la estandar por la tipo de área que es seleccionada.",
                            Strings.ROOM_AREA.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_areaHelp = new GridBagConstraints();
                gbc_areaHelp.anchor = GridBagConstraints.LINE_END;
                gbc_areaHelp.gridy = 1;
                gbc_areaHelp.gridx = 2;
                areaPanel.add(areaHelp, gbc_areaHelp);
                areaHelp.setVisible(false);
            }
            
            quantityPanel.setBorder(new TitledBorder(Strings.ROOM_QUANTITY.toString()));
            GridBagConstraints gbc_quantityPanel = new GridBagConstraints();
            gbc_quantityPanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_quantityPanel.insets = new Insets(0, 0, 5, 0);
            gbc_quantityPanel.gridx = 0;
            gbc_quantityPanel.gridy = 4;
            contentPanel.add(quantityPanel, gbc_quantityPanel);
            GridBagLayout gbl_quantityPanel = new GridBagLayout();
            quantityPanel.setLayout(gbl_quantityPanel);
            quantityPanel.setVisible(false);
            
            {
                Component verticalStrut = Box.createVerticalStrut(10);
                GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                gbc_verticalStrut.gridx = 0;
                gbc_verticalStrut.gridy = 0;
                quantityPanel.add(verticalStrut, gbc_verticalStrut);
            }
            {
                //Text input for quantity of rooms.
                roomQuantity.addFocusListener(new FocusListener() {
                    
                    @Override
                    public void focusGained(FocusEvent e){
                        roomQuantity.selectAll();
                    }
                    
                    @Override
                    public void focusLost(FocusEvent e) {
                    //Validate all inputs.   
                        String quantity = roomQuantity.getText();
                        if (quantity.matches(intregex)) {
                            room.setRoomQuantity(Integer.parseInt(quantity));
                        } else if (quantity.matches(doubleregex)) {
                            //Set roomarea to the number entered in the field.
                            BigDecimal value = new BigDecimal(Double.parseDouble(quantity));
                            value = value.setScale(0, RoundingMode.DOWN);
                            roomQuantity.setText(String.valueOf(value));
                            room.setRoomQuantity(Integer.parseInt(roomQuantity.getText()));
                        } else {
                            roomQuantity.setText("1");
                            room.setRoomQuantity(1);
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                        }
                    }
                });
                GridBagConstraints gbc_roomQuantity = new GridBagConstraints();
                gbc_roomQuantity.anchor = GridBagConstraints.CENTER;
                gbc_roomQuantity.fill = GridBagConstraints.HORIZONTAL;
                gbc_roomQuantity.gridy = 1;
                gbc_roomQuantity.gridx = 1;
                quantityPanel.add(roomQuantity, gbc_roomQuantity);
                roomQuantity.setColumns(10);
                roomQuantity.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                Component box = Box.createHorizontalStrut(325);
                GridBagConstraints gbc_box = new GridBagConstraints();
                gbc_box.gridy = 1;
                gbc_box.gridx = 1;
                quantityPanel.add(box, gbc_box);
            }
            {
                //Help dialog for room quantity
                quantityHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "El número de áreas idénticas para añadir a la industria.",
                            Strings.ROOM_QUANTITY.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_quantityHelp = new GridBagConstraints();
                gbc_quantityHelp.anchor = GridBagConstraints.LINE_END;
                gbc_quantityHelp.gridy = 1;
                gbc_quantityHelp.gridx = 2;
                quantityPanel.add(quantityHelp, gbc_quantityHelp);
            }
            {
                Component verticalStrut = Box.createVerticalStrut(10);
                GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                gbc_verticalStrut.insets = new Insets(0, 0, 0, 0);
                gbc_verticalStrut.gridx = 0;
                gbc_verticalStrut.gridy = 2;
                quantityPanel.add(verticalStrut, gbc_verticalStrut);
            }

            furnishingPanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.FURNISHING
                    .toString(), TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_furnishingPanel = new GridBagConstraints();
            gbc_furnishingPanel.fill = GridBagConstraints.BOTH;
            gbc_furnishingPanel.gridx = 0;
            gbc_furnishingPanel.gridy = 5;
            contentPanel.add(furnishingPanel, gbc_furnishingPanel);
            GridBagLayout gbl_furnishingPanel = new GridBagLayout();
            furnishingPanel.setLayout(gbl_furnishingPanel);
            furnishingPanel.setVisible(false);
            
            {
                //Display for furnshings added to the room
                JScrollPane scrollPane = new JScrollPane();
                GridBagConstraints gbc_scrollPane = new GridBagConstraints();
                gbc_scrollPane.fill = GridBagConstraints.BOTH;
                gbc_scrollPane.gridx = 0;
                gbc_scrollPane.gridwidth = 3;
                gbc_scrollPane.gridy = 0;
                furnishingPanel.add(scrollPane, gbc_scrollPane);
                {
                    furnishingList = new JList();
                    scrollPane.setViewportView(furnishingList);
                }
            }
            {
                //Button to add new furnishing to a room.
                JButton newItemButton = new JButton(Strings.ADD.toString()
                        + " " + Strings.FURNITURE_ITEM.toString() + "...");
                newItemButton.addActionListener((ActionEvent e) -> {
                    FurnishingDetailForm furnishingForm = new FurnishingDetailForm(
                            RoomDetailForm.this);
                });
                newItemButton.setHorizontalAlignment(SwingConstants.LEFT);
                GridBagConstraints gbc_newItemButton = new GridBagConstraints();
                gbc_newItemButton.anchor = GridBagConstraints.WEST;
                gbc_newItemButton.gridx = 0;
                gbc_newItemButton.gridy = 1;
                furnishingPanel.add(newItemButton, gbc_newItemButton);
            }
            {
                Component box = Box.createHorizontalStrut(165);
                GridBagConstraints gbc_box = new GridBagConstraints();
                gbc_box.anchor = GridBagConstraints.CENTER;
                gbc_box.gridy = 1;
                gbc_box.gridx = 1;
                furnishingPanel.add(box, gbc_box);
            }
            {
                //Help dialog for furnishings.
                furnishingHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Los meubles son objetos que se encuentran típicamente"
                                + " en el tipo de área seleccionado.\nHay dos opcionnes para añaden muebles:\n"
                                + "1) Seleccionar cada uno de los muebles por separado\n"
                                + "2) Elijir 'Área Estandar' que usa una carga media de este tipo de área",
                            Strings.FURNISHING.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_furnishingHelp = new GridBagConstraints();
                gbc_furnishingHelp.anchor = GridBagConstraints.CENTER;
                gbc_furnishingHelp.gridy = 1;
                gbc_furnishingHelp.gridx = 2;
                furnishingPanel.add(furnishingHelp, gbc_furnishingHelp);
            }
            
            finGoodStoragePanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.STORAGE_DETAILS
                    .toString(), TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_storagePanel = new GridBagConstraints();
            gbc_storagePanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_storagePanel.gridx = 0;
            gbc_storagePanel.gridy = 6;
            contentPanel.add(finGoodStoragePanel, gbc_storagePanel);
            GridBagLayout gbl_storagePanel = new GridBagLayout();
            finGoodStoragePanel.setLayout(gbl_storagePanel);
            finGoodStoragePanel.setVisible(false);
            
            {
                GridBagConstraints gbc_storageTypeLabel = new GridBagConstraints();
                gbc_storageTypeLabel.anchor = GridBagConstraints.CENTER;
                gbc_storageTypeLabel.gridx = 0;
                finGoodStoragePanel.add(storageTypeLabel, gbc_storageTypeLabel);
            }
            {
                //Drop down menu for type of storage.
                finGoodStorageType.addActionListener((ActionEvent e) -> {
                    room.setFinGoodStorageType((FinGoodStorageType) finGoodStorageType.getSelectedItem());
                });
                finGoodStorageType.setModel(new DefaultComboBoxModel(FinGoodStorageType.values()));
                GridBagConstraints gbc_finGoodStorageType = new GridBagConstraints();
                gbc_finGoodStorageType.anchor = GridBagConstraints.CENTER;
                gbc_finGoodStorageType.fill = GridBagConstraints.HORIZONTAL;
                gbc_finGoodStorageType.gridx = 1;
                finGoodStoragePanel.add(finGoodStorageType, gbc_finGoodStorageType);
            }
            {
                Component box = Box.createHorizontalStrut(235);
                GridBagConstraints gbc_box = new GridBagConstraints();
                gbc_box.anchor = GridBagConstraints.CENTER;
                gbc_box.gridx = 1;
                finGoodStoragePanel.add(box, gbc_box);
            }
            {
                //Help dialog for finished goods storage.
                finGoodStorageHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Selección de almacenamiento de los productos terminados.",
                            Strings.FIN_GOOD_STORE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_finGoodStorageHelp = new GridBagConstraints();
                gbc_finGoodStorageHelp.anchor = GridBagConstraints.LINE_END;
                gbc_finGoodStorageHelp.gridx = 2;
                finGoodStoragePanel.add(finGoodStorageHelp, gbc_finGoodStorageHelp);
            }
            
            rawMatStoragePanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.STORAGE_DETAILS
                    .toString(), TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_rawMatStoragePanel = new GridBagConstraints();
            gbc_rawMatStoragePanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_rawMatStoragePanel.gridx = 0;
            gbc_rawMatStoragePanel.gridy = 6;
            contentPanel.add(rawMatStoragePanel, gbc_rawMatStoragePanel);
            GridBagLayout gbl_rawMatStoragePanel = new GridBagLayout();
            rawMatStoragePanel.setLayout(gbl_rawMatStoragePanel);
            rawMatStoragePanel.setVisible(false);

            {
                GridBagConstraints gbc_rawStorageTypeLabel = new GridBagConstraints();
                gbc_rawStorageTypeLabel.anchor = GridBagConstraints.CENTER;
                rawMatStoragePanel.add(rawStorageTypeLabel, gbc_rawStorageTypeLabel);
            }
            {
                //Drop down menu for material storage type.
                rawMatStorageType.addActionListener((ActionEvent e) -> {
                    room.setRawMatStorageType((RawMatStorageType) rawMatStorageType.getSelectedItem());
                });
                rawMatStorageType.setModel(new DefaultComboBoxModel(RawMatStorageType.values()));
                GridBagConstraints gbc_rawMatStorageType = new GridBagConstraints();
                gbc_rawMatStorageType.anchor = GridBagConstraints.CENTER;
                gbc_rawMatStorageType.fill = GridBagConstraints.HORIZONTAL;
                rawMatStoragePanel.add(rawMatStorageType, gbc_rawMatStorageType);
            }
            {
                Component box = Box.createHorizontalStrut(205);
                GridBagConstraints gbc_box = new GridBagConstraints();
                gbc_box.anchor = GridBagConstraints.CENTER;
                gbc_box.gridx = 1;
                rawMatStoragePanel.add(box, gbc_box);
            }
            {
                //Help dialog for raw material storage options.
                rawMatStorageHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "Selección de almacenamiento de los materiales primas.",
                            Strings.RAW_STORE_TYPE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_rawMatStorageHelp = new GridBagConstraints();
                gbc_rawMatStorageHelp.anchor = GridBagConstraints.LINE_END;
                gbc_rawMatStorageHelp.gridx = 2;
                rawMatStoragePanel.add(rawMatStorageHelp, gbc_rawMatStorageHelp);
            }
            
            damagePanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.DAMAGE
                    .toString(), TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_damagePanel = new GridBagConstraints();
            gbc_damagePanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_damagePanel.gridx = 0;
            gbc_damagePanel.gridy = 7;
            contentPanel.add(damagePanel, gbc_damagePanel);
            GridBagLayout gbl_damagePanel = new GridBagLayout();
            damagePanel.setLayout(gbl_damagePanel);
            damagePanel.setVisible(false);
            {
                Component box = Box.createHorizontalStrut(105);
                GridBagConstraints gbc_box = new GridBagConstraints();
                gbc_box.gridy = 1;
                gbc_box.gridheight = 2;
                gbc_box.gridx = 0;
                damagePanel.add(box, gbc_box);
            }
            {
                JLabel lblNewLabel = new JLabel(
                        Strings.PERCENT_DAMAGE.toString() + ":");
                GridBagConstraints gbc_lblNewLabel = new GridBagConstraints();
                gbc_lblNewLabel.insets = new Insets(0, 0, 5, 5);
                gbc_lblNewLabel.gridx = 1;
                gbc_lblNewLabel.gridy = 0;
                damagePanel.add(lblNewLabel, gbc_lblNewLabel);
            }
            {

                GridBagConstraints gbc_damageLabel = new GridBagConstraints();
                gbc_damageLabel.anchor = GridBagConstraints.WEST;
                gbc_damageLabel.insets = new Insets(0, 0, 5, 0);
                gbc_damageLabel.gridx = 2;
                gbc_damageLabel.gridy = 0;
                damagePanel.add(damageLabel, gbc_damageLabel);
            }
            {
                //Slider to input damage percentage.
                damageSlider.addChangeListener((ChangeEvent arg0) -> {
                    damageLabel.setText(String.valueOf(damageSlider
                            .getValue()) + "%");
                    room.setDamage(damageSlider.getValue());
                });
                damageSlider.setValue(100);
                damageSlider.setMajorTickSpacing(10);
                damageSlider.setPaintTicks(true);
                damageSlider.setPaintLabels(true);
                GridBagConstraints gbc_damageSlider = new GridBagConstraints();
                gbc_damageSlider.anchor = GridBagConstraints.NORTH;
                gbc_damageSlider.gridx = 1;
                gbc_damageSlider.gridwidth = 2;
                gbc_damageSlider.gridy = 1;
                damagePanel.add(damageSlider, gbc_damageSlider);
            }
            {
                Component box = Box.createHorizontalStrut(30);
                GridBagConstraints gbc_box = new GridBagConstraints();
                gbc_box.gridy = 1;
                gbc_box.gridheight = 2;
                gbc_box.gridx = 3;
                damagePanel.add(box, gbc_box);
            }
            {
                //Help dialog for damage slider
                damageHelp.addActionListener((ActionEvent e) -> {
                    JOptionPane.showMessageDialog(null, "El porcentaje del área que fue dañado.",
                            Strings.DAMAGE.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                });
                GridBagConstraints gbc_damageHelp = new GridBagConstraints();
                gbc_damageHelp.anchor = GridBagConstraints.LINE_END;
                gbc_damageHelp.gridy = 0;
                gbc_damageHelp.gridx = 4;
                gbc_damageHelp.gridheight = 2;
                damagePanel.add(damageHelp, gbc_damageHelp);
            }
            
            fuelVolumePanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.FUEL_VOL.toString(),
                    TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_fuelVolumePanel = new GridBagConstraints();
            gbc_fuelVolumePanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_fuelVolumePanel.gridx = 0;
            gbc_fuelVolumePanel.gridy = 2;
            contentPanel.add(fuelVolumePanel, gbc_fuelVolumePanel);
            GridBagLayout gbl_fuelVolumePanel = new GridBagLayout();
            fuelVolumePanel.setLayout(gbl_fuelVolumePanel);
            fuelVolumePanel.setVisible(false);
            {
                //Text input for volume of fuel.
                fuelVolumeText.addFocusListener(new FocusListener() {
                    
                    @Override
                    public void focusGained(FocusEvent e){
                        fuelVolumeText.selectAll();
                    }
                    
                    @Override
                    public void focusLost(FocusEvent e) {
                        String fuelVolume = fuelVolumeText.getText();
                        if (fuelVolume.matches(doubleregex)) {
                            room.setFuelVolume(Double.parseDouble(fuelVolume));
                        } else if (fuelVolume.matches(intregex)) {
                            room.setFuelVolume(Double.parseDouble(fuelVolume + ".0"));
                            fuelVolumeText.setText(String.valueOf(room.getFuelVolume()));
                        }
                    }
                });
                GridBagConstraints gbc_fuelVolumeText = new GridBagConstraints();
                gbc_fuelVolumeText.anchor = GridBagConstraints.CENTER;
                gbc_fuelVolumeText.gridy = 1;
                fuelVolumePanel.add(fuelVolumeText, gbc_fuelVolumeText);
                fuelVolumeText.setColumns(10);
                fuelVolumeText.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                Component verticalStrut = Box.createVerticalStrut(5);
                GridBagConstraints gbc_verticalStrut = new GridBagConstraints();
                gbc_verticalStrut.anchor = GridBagConstraints.CENTER;
                gbc_verticalStrut.gridy = 2;
                fuelVolumePanel.add(verticalStrut, gbc_verticalStrut);
            }
            {
                GridBagConstraints gbc_fuelVolumeLabel = new GridBagConstraints();
                gbc_fuelVolumeLabel.anchor = GridBagConstraints.CENTER;
                gbc_fuelVolumeLabel.gridy = 1;
                fuelVolumePanel.add(fuelVolumeLabel, gbc_fuelVolumeLabel);
            }
            
            finGoodDetailsPanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.FIN_GOOD_DET.toString(),
                    TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_finGoodDetailsPanel = new GridBagConstraints();
            gbc_finGoodDetailsPanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_finGoodDetailsPanel.gridx = 0;
            gbc_finGoodDetailsPanel.gridy = 2;
            contentPanel.add(finGoodDetailsPanel, gbc_finGoodDetailsPanel);
            GridBagLayout gbl_finGoodDetailsPanel = new GridBagLayout();
            finGoodDetailsPanel.setLayout(gbl_finGoodDetailsPanel);
            finGoodDetailsPanel.setVisible(false);
            
            {
                //Radio button to select use of volume/density
                finGoodVolumeRadio.setText(Strings.USE_VOL.toString());
                finGoodVolumeRadio.addActionListener((ActionEvent e) -> {
                    finGoodMatDensity.setEnabled(true);
                    finGoodMatVolume.setEnabled(true);
                    finGoodMatMass.setEnabled(false);
                    finGoodMassRadio.setSelected(false);
                    finGoodVolumeRadio.setSelected(true);
                });
                GridBagConstraints gbc_volumeRadio = new GridBagConstraints();
                gbc_volumeRadio.anchor = GridBagConstraints.LINE_START;
                gbc_volumeRadio.gridy = 0;
                finGoodDetailsPanel.add(finGoodVolumeRadio, gbc_volumeRadio);
            }
            {
                JLabel densityLabel = new JLabel(Strings.DENSITY.toString() + ":");
                GridBagConstraints gbc_densityLabel = new GridBagConstraints();
                gbc_densityLabel.anchor = GridBagConstraints.CENTER;
                gbc_densityLabel.gridy = 1;
                finGoodDetailsPanel.add(densityLabel, gbc_densityLabel);
            }
            {
                //Text input for density of finished good.
                finGoodMatDensity.addFocusListener(new FocusListener() {
                    @Override
                    public void focusGained(FocusEvent e) {
                        finGoodMatDensity.selectAll();

                    }
                    @Override
                    public void focusLost(FocusEvent e) {
                        String value = finGoodMatDensity.getText();
                        if (value.matches(intregex)) {
                            double massDouble = Double.parseDouble(finGoodMatDensity.getText()) * Double.parseDouble(finGoodMatVolume.getText());
                            finGoodMatDensity.setText(value + ".00");
                            finGoodMatMass.setText(String.format("%.2f", massDouble));
                        } else if (value.matches(doubleregex)) {
                            double massDouble = Double.parseDouble(finGoodMatDensity.getText()) * Double.parseDouble(finGoodMatVolume.getText());
                            finGoodMatMass.setText(String.format("%.2f", massDouble));
                        } else {
                            finGoodMatDensity.setText("1.00");
                            double massDouble = Double.parseDouble(finGoodMatDensity.getText()) * Double.parseDouble(finGoodMatVolume.getText());
                            finGoodMatMass.setText(String.format("%.2f", massDouble));
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                        }
                    }
                });
                GridBagConstraints gbc_matDensity = new GridBagConstraints();
                gbc_matDensity.anchor = GridBagConstraints.CENTER;
                gbc_matDensity.gridy = 1;
                finGoodDetailsPanel.add(finGoodMatDensity, gbc_matDensity);
                finGoodMatDensity.setColumns(10);
                finGoodMatDensity.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                JLabel densityUnits = new JLabel("kg / m^3");
                GridBagConstraints gbc_densityUnits = new GridBagConstraints();
                gbc_densityUnits.anchor = GridBagConstraints.CENTER;
                gbc_densityUnits.gridy = 1;
                finGoodDetailsPanel.add(densityUnits, gbc_densityUnits);
            }
            {
                JLabel volumeLabel = new JLabel(Strings.VOLUME.toString() + ":");
                GridBagConstraints gbc_volumeLabel = new GridBagConstraints();
                gbc_volumeLabel.anchor = GridBagConstraints.CENTER;
                gbc_volumeLabel.gridy = 2;
                finGoodDetailsPanel.add(volumeLabel, gbc_volumeLabel);
            }
            {
                //Text input for finished good volume.
                finGoodMatVolume.addFocusListener(new FocusListener() {
                @Override
                public void focusGained(FocusEvent e) {
                    finGoodMatVolume.selectAll();
                }
                @Override
                public void focusLost(FocusEvent e) {
                    String value = finGoodMatVolume.getText();
                    if (value.matches(intregex)) {
                        finGoodMatVolume.setText(value + ".00");
                        double massDouble = Double.parseDouble(finGoodMatDensity.getText())
                            * Double.parseDouble(finGoodMatVolume.getText());
                        finGoodMatMass.setText(String.format("%.2f", massDouble));
                    } else if (value.matches(doubleregex)) {
                        double massDouble = Double.parseDouble(finGoodMatDensity.getText())
                            * Double.parseDouble(finGoodMatVolume.getText());
                        finGoodMatMass.setText(String.format("%.2f", massDouble));
                    } else {
                        finGoodMatVolume.setText("1.00");
                        double massDouble = Double.parseDouble(finGoodMatDensity.getText())
                            * Double.parseDouble(finGoodMatVolume.getText());
                        finGoodMatMass.setText(String.format("%.2f", massDouble));
                        JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                    }
                }
                });
                GridBagConstraints gbc_matVolume = new GridBagConstraints();
                gbc_matVolume.anchor = GridBagConstraints.CENTER;
                gbc_matVolume.gridy = 2;
                finGoodDetailsPanel.add(finGoodMatVolume, gbc_matVolume);
                finGoodMatVolume.setColumns(10);
                finGoodMatVolume.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                JLabel volumeUnits = new JLabel("m^3");
                GridBagConstraints gbc_volumeUnits = new GridBagConstraints();
                gbc_volumeUnits.anchor = GridBagConstraints.CENTER;
                gbc_volumeUnits.gridy = 2;
                finGoodDetailsPanel.add(volumeUnits, gbc_volumeUnits);
            }
            {
                //Radio button to select use of mass.
                finGoodMassRadio.setText(Strings.USE_MASS.toString());
                finGoodMassRadio.addActionListener((ActionEvent e) -> {
                    finGoodMatMass.setEnabled(true);
                    finGoodMatVolume.setEnabled(false);
                    finGoodMatDensity.setEnabled(false);
                    finGoodVolumeRadio.setSelected(false);
                    finGoodMassRadio.setSelected(true);
                });
                GridBagConstraints gbc_massRadio = new GridBagConstraints();
                gbc_massRadio.anchor = GridBagConstraints.LINE_START;
                gbc_massRadio.gridy = 3;
                finGoodDetailsPanel.add(finGoodMassRadio, gbc_massRadio);
            }
            {
                JLabel massLabel = new JLabel(Strings.MASS.toString() + ":");
                GridBagConstraints gbc_massLabel = new GridBagConstraints();
                gbc_massLabel.anchor = GridBagConstraints.CENTER;
                gbc_massLabel.gridy = 4;
                finGoodDetailsPanel.add(massLabel, gbc_massLabel);
            }
            {
                //Text input for mass of finished good.
                finGoodMatMass.addFocusListener(new FocusListener() {
                    @Override
                    public void focusGained(FocusEvent e) {
                        finGoodMatMass.selectAll();
                    }
                    @Override
                    public void focusLost(FocusEvent e) {
                        double massdouble = 0.0;
                        if (finGoodMatMass.getText().matches(doubleregex)) {
                            massdouble = Double.parseDouble(finGoodMatMass.getText());
                            finGoodMatMass.setText(String.format("%.2f", massdouble));
                            room.setMatMass(Double.parseDouble(finGoodMatMass.getText()));
                        } else if (finGoodMatMass.getText().matches(intregex)) {
                            massdouble = Double.parseDouble(finGoodMatMass.getText() + ".0");
                            finGoodMatMass.setText(String.format("%.2f", massdouble));
                            room.setMatMass(Double.parseDouble(finGoodMatMass.getText()));
                        } else {
                            finGoodMatMass.setText("1.00");
                            room.setMatMass(1.00);
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                        }
                    }
                });
                GridBagConstraints gbc_matMass = new GridBagConstraints();
                gbc_matMass.anchor = GridBagConstraints.CENTER;
                gbc_matMass.gridy = 4;
                finGoodDetailsPanel.add(finGoodMatMass, gbc_matMass);
                finGoodMatMass.setEnabled(false);
                finGoodMatMass.setColumns(10);
                finGoodMatMass.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                JLabel massUnits = new JLabel("kg");
                GridBagConstraints gbc_massUnits = new GridBagConstraints();
                gbc_massUnits.anchor = GridBagConstraints.CENTER;
                gbc_massUnits.gridy = 4;
                finGoodDetailsPanel.add(massUnits, gbc_massUnits);
            }
            
            rawMatDetailsPanel.setBorder(new TitledBorder(new EtchedBorder(
                    EtchedBorder.LOWERED, null, null), Strings.RAW_MAT_DET.toString(),
                    TitledBorder.LEADING, TitledBorder.TOP, null,
                    null));
            GridBagConstraints gbc_rawMatDetailsPanel = new GridBagConstraints();
            gbc_rawMatDetailsPanel.fill = GridBagConstraints.HORIZONTAL;
            gbc_rawMatDetailsPanel.gridx = 0;
            gbc_rawMatDetailsPanel.gridy = 3;
            contentPanel.add(rawMatDetailsPanel, gbc_rawMatDetailsPanel);
            GridBagLayout gbl_rawMatDetailsPanel = new GridBagLayout();
            rawMatDetailsPanel.setLayout(gbl_rawMatDetailsPanel);
            rawMatDetailsPanel.setVisible(false);
            
            JPanel buttonPane = new JPanel();
            buttonPane.setLayout(new FlowLayout(FlowLayout.RIGHT));
            getContentPane().add(buttonPane, BorderLayout.SOUTH);
            buttonPane.setVisible(true);
            
            {
                //Radio button to select use of volume/density
                rawMatVolumeRadio.setText(Strings.USE_VOL.toString());
                rawMatVolumeRadio.addActionListener((ActionEvent e) -> {
                    rawMatDensity.setEnabled(true);
                    rawMatVolume.setEnabled(true);
                    rawMatMass.setEnabled(false);
                    rawMatMassRadio.setSelected(false);
                    rawMatVolumeRadio.setSelected(true);
                });
                GridBagConstraints gbc_volumeRadio = new GridBagConstraints();
                gbc_volumeRadio.anchor = GridBagConstraints.LINE_START;
                gbc_volumeRadio.gridy = 0;
                rawMatDetailsPanel.add(rawMatVolumeRadio, gbc_volumeRadio);
            }
            {
                JLabel densityLabel = new JLabel(Strings.DENSITY.toString() + ":");
                GridBagConstraints gbc_densityLabel = new GridBagConstraints();
                gbc_densityLabel.anchor = GridBagConstraints.CENTER;
                gbc_densityLabel.gridy = 1;
                rawMatDetailsPanel.add(densityLabel, gbc_densityLabel);
            }
            {
                //Text input for raw material density
                rawMatDensity.addFocusListener(new FocusListener() {
                    @Override
                    public void focusGained(FocusEvent e) {
                        rawMatDensity.selectAll();

                    }
                    @Override
                    public void focusLost(FocusEvent e) {
                        String value = rawMatDensity.getText();
                        if (value.matches(intregex)) {
                            double massDouble = Double.parseDouble(rawMatDensity.getText()) * Double.parseDouble(rawMatVolume.getText());
                            rawMatDensity.setText(value + ".00");
                            rawMatMass.setText(String.format("%.2f", massDouble));
                        } else if (value.matches(doubleregex)) {
                            double massDouble = Double.parseDouble(rawMatDensity.getText()) * Double.parseDouble(rawMatVolume.getText());
                            rawMatMass.setText(String.format("%.2f", massDouble));
                        } else {
                            rawMatDensity.setText("1.00");
                            double massDouble = Double.parseDouble(rawMatDensity.getText()) * Double.parseDouble(rawMatVolume.getText());
                            rawMatMass.setText(String.format("%.2f", massDouble));
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                        }
                    }
                });
                GridBagConstraints gbc_matDensity = new GridBagConstraints();
                gbc_matDensity.anchor = GridBagConstraints.CENTER;
                gbc_matDensity.gridy = 1;
                rawMatDetailsPanel.add(rawMatDensity, gbc_matDensity);
                rawMatDensity.setColumns(10);
                rawMatDensity.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                JLabel densityUnits = new JLabel("kg / m^3");
                GridBagConstraints gbc_densityUnits = new GridBagConstraints();
                gbc_densityUnits.anchor = GridBagConstraints.CENTER;
                gbc_densityUnits.gridy = 1;
                rawMatDetailsPanel.add(densityUnits, gbc_densityUnits);
            }
            {
                JLabel volumeLabel = new JLabel(Strings.VOLUME.toString() + ":");
                GridBagConstraints gbc_volumeLabel = new GridBagConstraints();
                gbc_volumeLabel.anchor = GridBagConstraints.CENTER;
                gbc_volumeLabel.gridy = 2;
                rawMatDetailsPanel.add(volumeLabel, gbc_volumeLabel);
            }
            {
                //Text input for raw material volume.
                rawMatVolume.addFocusListener(new FocusListener() {
                @Override
                public void focusGained(FocusEvent e) {
                    rawMatVolume.selectAll();
                }
                @Override
                public void focusLost(FocusEvent e) {
                    String value = rawMatVolume.getText();
                    if (value.matches(intregex)) {
                        rawMatVolume.setText(value + ".00");
                        double massDouble = Double.parseDouble(rawMatDensity.getText())
                            * Double.parseDouble(rawMatVolume.getText());
                        rawMatMass.setText(String.format("%.2f", massDouble));
                    } else if (value.matches(doubleregex)) {
                        double massDouble = Double.parseDouble(rawMatDensity.getText())
                            * Double.parseDouble(rawMatVolume.getText());
                        rawMatMass.setText(String.format("%.2f", massDouble));
                    } else {
                        rawMatVolume.setText("1.00");
                        double massDouble = Double.parseDouble(rawMatDensity.getText())
                            * Double.parseDouble(rawMatVolume.getText());
                        rawMatMass.setText(String.format("%.2f", massDouble));
                        JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                    }
                }
                });
                GridBagConstraints gbc_matVolume = new GridBagConstraints();
                gbc_matVolume.anchor = GridBagConstraints.CENTER;
                gbc_matVolume.gridy = 2;
                rawMatDetailsPanel.add(rawMatVolume, gbc_matVolume);
                rawMatVolume.setColumns(10);
                rawMatVolume.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                JLabel volumeUnits = new JLabel("m^3");
                GridBagConstraints gbc_volumeUnits = new GridBagConstraints();
                gbc_volumeUnits.anchor = GridBagConstraints.CENTER;
                gbc_volumeUnits.gridy = 2;
                rawMatDetailsPanel.add(volumeUnits, gbc_volumeUnits);
            }
            {
                //Radio button to select use of raw material mass.
                rawMatMassRadio.setText(Strings.USE_MASS.toString());
                rawMatMassRadio.addActionListener((ActionEvent e) -> {
                    rawMatMass.setEnabled(true);
                    rawMatVolume.setEnabled(false);
                    rawMatDensity.setEnabled(false);
                    rawMatVolumeRadio.setSelected(false);
                    rawMatMassRadio.setSelected(true);
                });
                GridBagConstraints gbc_massRadio = new GridBagConstraints();
                gbc_massRadio.anchor = GridBagConstraints.LINE_START;
                gbc_massRadio.gridy = 3;
                rawMatDetailsPanel.add(rawMatMassRadio, gbc_massRadio);
            }
            {
                JLabel massLabel = new JLabel(Strings.MASS.toString() + ":");
                GridBagConstraints gbc_massLabel = new GridBagConstraints();
                gbc_massLabel.anchor = GridBagConstraints.CENTER;
                gbc_massLabel.gridy = 4;
                rawMatDetailsPanel.add(massLabel, gbc_massLabel);
            }
            {
                //Text input for raw material mass.
                rawMatMass.addFocusListener(new FocusListener() {
                    @Override
                    public void focusGained(FocusEvent e) {
                        rawMatMass.selectAll();
                    }
                    @Override
                    public void focusLost(FocusEvent e) {
                        double massdouble = 0.0;
                        if (rawMatMass.getText().matches(doubleregex)) {
                            massdouble = Double.parseDouble(rawMatMass.getText());
                            rawMatMass.setText(String.format("%.2f", massdouble));
                            room.setRawMatMass(Double.parseDouble(rawMatMass.getText()));
                        } else if (rawMatMass.getText().matches(intregex)) {
                            massdouble = Double.parseDouble(rawMatMass.getText() + ".0");
                            rawMatMass.setText(String.format("%.2f", massdouble));
                            room.setRawMatMass(Double.parseDouble(rawMatMass.getText()));
                        } else {
                            rawMatMass.setText("1.00");
                            room.setRawMatMass(1.00);
                            JOptionPane.showMessageDialog(null, Strings.ERROR_BASE);
                        }
                    }
                });
                GridBagConstraints gbc_matMass = new GridBagConstraints();
                gbc_matMass.anchor = GridBagConstraints.CENTER;
                gbc_matMass.gridy = 4;
                rawMatDetailsPanel.add(rawMatMass, gbc_matMass);
                rawMatMass.setEnabled(false);
                rawMatMass.setColumns(10);
                rawMatMass.setHorizontalAlignment(SwingConstants.CENTER);
            }
            {
                JLabel massUnits = new JLabel("kg");
                GridBagConstraints gbc_massUnits = new GridBagConstraints();
                gbc_massUnits.anchor = GridBagConstraints.CENTER;
                gbc_massUnits.gridy = 4;
                rawMatDetailsPanel.add(massUnits, gbc_massUnits);
            }
            
            {
                //Button to cancel room detail input form.
                JButton cancelButton = new JButton(Strings.CANCEL.toString());
                cancelButton.addActionListener((ActionEvent e) -> {
                    contentPanel.setVisible(false);
                    dispose();
                });
                buttonPane.add(cancelButton);
            }
            {
                //Button to add room to current model.  Include validation checks.
                JButton addButton = new JButton(Strings.ADD.toString());
                addButton.addActionListener((ActionEvent e) -> {
                    ImageIcon shpi = new ImageIcon(RoomDetailForm.class.getResource("/sa/shpi/assets/shpismall.jpg"));
                    /*
                     * Makes sure that all values have been initialized correctly.
                     * Makes sure that room area will not exceed structure area.
                     */
                    if (roomTypeComboBox.getSelectedItem() == null) {
                        JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.ROOM_TYPE, Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        setVisible(true);
                    } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.FIN_GOOD_STORE)) {
                        if (room.getFinGoodType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.FIN_GOOD_TYPE.toString(), Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        } else if (room.getFinGoodStorageType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.FIN_STORE_TYPE.toString(), Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        } else {
                            int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, shpi);
                            if (response == JOptionPane.CANCEL_OPTION) {
                                setVisible(true);
                            } else if (response == JOptionPane.OK_OPTION) {
                                room.setMatMass(Double.parseDouble(finGoodMatMass.getText()));
                                parent.addRoom(room);
                                dispose();
                                contentPanel.setVisible(false);
                            }
                        }
                    } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.RAW_MAT_STORAGE)) {
                        if(room.getRawMatType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.RAW_MAT_TYPE.toString(), Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        } else if (room.getRawMatStorageType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.RAW_STORE_TYPE.toString(), Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        } else {
                            int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, shpi);
                            if (response == JOptionPane.CANCEL_OPTION) {
                                setVisible(true);
                            } else if (response == JOptionPane.OK_OPTION) {
                                room.setRawMatMass(Double.parseDouble(rawMatMass.getText()));
                                parent.addRoom(room);
                                dispose();
                                contentPanel.setVisible(false);
                            }
                        }
                        
                    } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.FUEL_STORE)) {
                        if (room.getFuelType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.FUEL_TYPE.toString(), Strings.ERROR.toString(), JOptionPane.INFORMATION_MESSAGE, shpi);
                        } else {
                            int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, shpi);
                            if (response == JOptionPane.CANCEL_OPTION) {
                                setVisible(true);
                            } else if (response == JOptionPane.OK_OPTION) {
                                parent.addRoom(room);
                                dispose();
                                contentPanel.setVisible(false);
                            }
                        }
                    } else if (roomTypeComboBox.getSelectedItem().equals(RoomType.PROD_FLOOR)) {
                        if (room.getFinGoodType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.FIN_GOOD_TYPE.toString());
                        } else if (room.getRawMatType() == null) {
                            JOptionPane.showMessageDialog(null, Strings.PLEASE_CHOOSE.toString() + " " + Strings.RAW_MAT_TYPE.toString());
                        } else {
                            int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, shpi);
                            if (response == JOptionPane.CANCEL_OPTION) {
                                setVisible(true);
                            } else if (response == JOptionPane.OK_OPTION) {
                                room.setMatMass(Double.parseDouble(finGoodMatMass.getText()));
                                room.setRawMatMass(Double.parseDouble(rawMatMass.getText()));
                                parent.addRoom(room);
                                dispose();
                                contentPanel.setVisible(false);
                            }
                        }
                    } else if ((Industrial.totalRoomArea + (room.getRoomArea() * room.getRoomQuantity())) > Industrial.getAreaTotal()) {
                        JOptionPane.showMessageDialog(null, Strings.ROOM_AREA_BIGGER);
                        //Subtract the added room area.
                        contentPanel.setVisible(true);
                    } else {
                        //Confirm info before adding.  Dialog panel.
                        int response = JOptionPane.showConfirmDialog(null, Strings.CONFIRM_DATA, Strings.CONFIRM.toString(), JOptionPane.OK_CANCEL_OPTION, JOptionPane.INFORMATION_MESSAGE, shpi);
                        if (response == JOptionPane.CANCEL_OPTION) {
                            setVisible(true);
                        } else if (response == JOptionPane.OK_OPTION) {
                            Industrial.addTotalRoomArea(room.getRoomArea() * room.getRoomQuantity());
                            room.setMatMass(Double.parseDouble(finGoodMatMass.getText()));
                            room.setRawMatMass(Double.parseDouble(rawMatMass.getText()));
                            parent.addRoom(room);
                            dispose();
                            contentPanel.setVisible(false);
                        }
                    }
                    
                });
                buttonPane.add(addButton);
                //Sets the default highlighted button.
                getRootPane().setDefaultButton(addButton);
            } 
            
        setVisible(true);
    }
    
    public AdvancedMainForm getParentForm() {
        return parent;
    }

    public void addFurnitureItem(UsedFurnishing uFurnishing) {
        //Get furnishing item from the furnishing detail form and add it to the room.
        room.addFurnishing(uFurnishing);

        DefaultListModel<UsedFurnishing> defaultListModel = new DefaultListModel<UsedFurnishing>();
        FurnishingList roomFurnishingList = room.getFurnishingList();
        for (int count = 0; count < roomFurnishingList.size(); count++) {
            defaultListModel.addElement(roomFurnishingList.get(count));
        }
        furnishingList.setModel(defaultListModel);
    }
    
}